@@ -1,4 +1,4 @@
-#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2020, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -59,9 +59,8 @@ def main():
 
     Options.parseArgs()
 
-    import logging  # isort:skip
-
-    logging.basicConfig(format="Nuitka:%(levelname)s:%(message)s")
+    # TODO: Stop using logging module, then this can be removed.
+    from nuitka import Tracing  # isort:skip
 
     # We don't care, and these are triggered by run time calculations of "range" and
     # others, while on python2.7 they are disabled by default.
@@ -133,24 +132,38 @@ def main():
 
         Execution.callExec(args)
 
-    if Options.isShowMemory():
-        from nuitka.utils import MemoryUsage
-
-        MemoryUsage.startMemoryTracing()
-
     # Inform the user about potential issues.
     from nuitka.PythonVersions import getSupportedPythonVersions
 
     if current_version not in getSupportedPythonVersions():
-
         # Do not disturb run of automatic tests, detected from the presence of
         # that environment variable.
         if "PYTHON" not in os.environ:
-            logging.warning(
+            Tracing.general.warning(
                 "The version '%s' is not currently supported. Expect problems.",
                 current_version,
             )
 
+    if os.name == "nt":
+        # Windows store Python's don't allow looking at the python, catch that.
+        try:
+            with open(sys.executable):
+                pass
+        except OSError:
+            sys.exit(
+                "Error, the Python from Windows store is not supported, check user manual."
+            )
+
+    # Load plugins after we know, we don't execute again.
+    from nuitka.plugins.Plugins import activatePlugins
+
+    activatePlugins()
+
+    if Options.isShowMemory():
+        from nuitka.utils import MemoryUsage
+
+        MemoryUsage.startMemoryTracing()
+
     if "NUITKA_NAMESPACES" in os.environ:
         # Restore the detected name space packages, that were force loaded in
         # site.py, and will need a free pass later on. pylint: disable=eval-used
