@@ -1,4 +1,4 @@
-#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2020, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -21,7 +21,10 @@
 
 from nuitka.PythonVersions import python_version
 
-from .CodeHelpers import generateExpressionCode, withObjectCodeTemporaryAssignment
+from .CodeHelpers import (
+    generateExpressionCode,
+    withObjectCodeTemporaryAssignment,
+)
 from .templates.CodeTemplatesExceptions import template_publish_exception_to_handler
 
 
@@ -48,7 +51,7 @@ def getTracebackMakingIdentifier(context, lineno_name):
     frame_handle = context.getFrameHandle()
     assert frame_handle is not None
 
-    return "MAKE_TRACEBACK( %s, %s )" % (frame_handle, lineno_name)
+    return "MAKE_TRACEBACK(%s, %s)" % (frame_handle, lineno_name)
 
 
 def generateExceptionCaughtTypeCode(to_name, expression, emit, context):
@@ -95,13 +98,10 @@ def generateExceptionCaughtTracebackCode(to_name, expression, emit, context):
         else:
             emit(
                 """\
-if ( %(keeper_tb)s != NULL )
-{
+if (%(keeper_tb)s != NULL) {
     %(to_name)s = (PyObject *)%(keeper_tb)s;
-    Py_INCREF( %(to_name)s );
-}
-else
-{
+    Py_INCREF(%(to_name)s);
+} else {
     %(to_name)s = (PyObject *)%(tb_making)s;
 }
 """
@@ -121,18 +121,21 @@ def getExceptionUnpublishedReleaseCode(emit, context):
     keeper_variables = context.getExceptionKeeperVariables()
 
     if keeper_variables[0] is not None:
-        emit("Py_DECREF( %s );" % keeper_variables[0])
-        emit("Py_XDECREF( %s );" % keeper_variables[1])
-        emit("Py_XDECREF( %s );" % keeper_variables[2])
+        emit("Py_DECREF(%s);" % keeper_variables[0])
+        emit("Py_XDECREF(%s);" % keeper_variables[1])
+        emit("Py_XDECREF(%s);" % keeper_variables[2])
 
 
 def generateExceptionPublishCode(statement, emit, context):
     # This statement has no attributes really, pylint: disable=unused-argument
 
     # Current variables cannot be used anymore now.
-    keeper_type, keeper_value, keeper_tb, keeper_lineno = context.setExceptionKeeperVariables(
-        (None, None, None, None)
-    )
+    (
+        keeper_type,
+        keeper_value,
+        keeper_tb,
+        keeper_lineno,
+    ) = context.setExceptionKeeperVariables((None, None, None, None))
 
     emit(
         template_publish_exception_to_handler
@@ -146,20 +149,19 @@ def generateExceptionPublishCode(statement, emit, context):
         }
     )
 
-    emit(
-        "NORMALIZE_EXCEPTION( &%s, &%s, &%s );" % (keeper_type, keeper_value, keeper_tb)
-    )
+    emit("NORMALIZE_EXCEPTION(&%s, &%s, &%s);" % (keeper_type, keeper_value, keeper_tb))
 
     if python_version >= 300:
         emit(
-            "PyException_SetTraceback( %s, (PyObject *)%s );"
-            % (keeper_value, keeper_tb)
+            "PyException_SetTraceback(%s, (PyObject *)%s);" % (keeper_value, keeper_tb)
         )
 
-    emit("PUBLISH_EXCEPTION( &%s, &%s, &%s );" % (keeper_type, keeper_value, keeper_tb))
+    emit("PUBLISH_EXCEPTION(&%s, &%s, &%s);" % (keeper_type, keeper_value, keeper_tb))
 
 
 def generateBuiltinMakeExceptionCode(to_name, expression, emit, context):
+    # We try to make optimal code for various cases, pylint: disable=too-many-locals
+
     from .CallCodes import getCallCodeNoArgs, getCallCodePosArgsQuick
 
     exception_arg_names = []
@@ -200,3 +202,54 @@ def generateBuiltinMakeExceptionCode(to_name, expression, emit, context):
                 emit=emit,
                 context=context,
             )
+
+        if expression.getExceptionName() == "ImportError" and python_version >= 300:
+            from .PythonAPICodes import getReferenceExportCode
+
+            import_error_name_expression = expression.getImportErrorName()
+
+            if import_error_name_expression is not None:
+                exception_importerror_name = context.allocateTempName(
+                    "make_exception_importerror_name"
+                )
+
+                generateExpressionCode(
+                    to_name=exception_importerror_name,
+                    expression=import_error_name_expression,
+                    emit=emit,
+                    context=context,
+                    allow_none=True,
+                )
+
+                getReferenceExportCode(exception_importerror_name, emit, context)
+                if context.needsCleanup(exception_importerror_name):
+                    context.removeCleanupTempName(exception_importerror_name)
+
+                emit(
+                    "((PyImportErrorObject *)%s)->name = %s;"
+                    % (to_name, exception_importerror_name)
+                )
+
+            import_error_path_expression = expression.getImportErrorPath()
+
+            if import_error_path_expression is not None:
+                exception_importerror_path = context.allocateTempName(
+                    "make_exception_importerror_path"
+                )
+
+                generateExpressionCode(
+                    to_name=exception_importerror_path,
+                    expression=import_error_path_expression,
+                    emit=emit,
+                    context=context,
+                    allow_none=True,
+                )
+
+                getReferenceExportCode(exception_importerror_path, emit, context)
+                if context.needsCleanup(exception_importerror_path):
+                    context.removeCleanupTempName(exception_importerror_path)
+
+                emit(
+                    "((PyImportErrorObject *)%s)->path = %s;"
+                    % (to_name, exception_importerror_path)
+                )
