@@ -1,4 +1,4 @@
-#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2020, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -19,9 +19,9 @@
 
 """
 
-from logging import warning
 
 from nuitka.PythonVersions import python_version
+from nuitka.Tracing import general
 
 from .c_types.CTypePyObjectPtrs import CTypeCellObject, CTypePyObjectPtrPtr
 from .CodeHelpers import (
@@ -45,10 +45,13 @@ from .templates.CodeTemplatesFunction import (
     template_function_make_declaration,
     template_function_return_exit,
     template_make_function,
-    template_make_function_body,
+    template_maker_function_body,
 )
 from .TupleCodes import getTupleCreationCode
-from .VariableCodes import decideLocalVariableCodeType, getLocalVariableDeclaration
+from .VariableCodes import (
+    decideLocalVariableCodeType,
+    getLocalVariableDeclaration,
+)
 
 
 def _getFunctionCreationArgs(defaults_name, kw_defaults_name, annotations_name):
@@ -86,6 +89,10 @@ def _getFunctionEntryPointIdentifier(function_identifier):
     return "impl_" + function_identifier
 
 
+def _getFunctionMakerIdentifier(function_identifier):
+    return "MAKE_FUNCTION_" + function_identifier
+
+
 def getFunctionQualnameObj(owner, context):
     """ Get code to pass to function alike object creation for qualname.
 
@@ -135,27 +142,43 @@ def getFunctionMakerCode(
     else:
         function_doc = context.getConstantCode(constant=function_doc)
 
-    result = template_make_function_body % {
+    if function_body.getBody() is None:
+        function_impl_identifier = "NULL"
+    else:
+        function_impl_identifier = _getFunctionEntryPointIdentifier(
+            function_identifier=function_identifier
+        )
+
+    function_maker_identifier = _getFunctionMakerIdentifier(
+        function_identifier=function_identifier
+    )
+
+    code_identifier = context.getCodeObjectHandle(
+        code_object=function_body.getCodeObject()
+    )
+
+    module_identifier = getModuleAccessCode(context=context)
+
+    result = template_maker_function_body % {
         "function_name_obj": context.getConstantCode(
             constant=function_body.getFunctionName()
         ),
         "function_qualname_obj": getFunctionQualnameObj(function_body, context),
-        "function_identifier": function_identifier,
-        "function_impl_identifier": _getFunctionEntryPointIdentifier(
-            function_identifier=function_identifier
-        ),
+        "function_maker_identifier": function_maker_identifier,
+        "function_impl_identifier": function_impl_identifier,
         "function_creation_args": ", ".join(function_creation_args),
-        "code_identifier": context.getCodeObjectHandle(
-            code_object=function_body.getCodeObject()
-        ),
+        "code_identifier": code_identifier,
         "function_doc": function_doc,
         "defaults": "defaults" if defaults_name else "NULL",
         "kw_defaults": "kw_defaults" if kw_defaults_name else "NULL",
         "annotations": "annotations" if annotations_name else "NULL",
         "closure_count": len(closure_variables),
-        "module_identifier": getModuleAccessCode(context=context),
+        "module_identifier": module_identifier,
     }
 
+    # TODO: Make it optional.
+    context.addFunctionCreationInfo(function_impl_identifier)
+
     return result
 
 
@@ -313,11 +336,15 @@ def getFunctionCreationCode(
         context=context,
     )
 
+    function_maker_identifier = _getFunctionMakerIdentifier(
+        function_identifier=function_identifier
+    )
+
     emit(
         template_make_function
         % {
             "to_name": to_name,
-            "function_identifier": function_identifier,
+            "function_maker_identifier": function_maker_identifier,
             "args": ", ".join(str(arg) for arg in args),
             "closure_copy": indented(closure_copy, 0, True),
         }
@@ -370,14 +397,14 @@ def getDirectFunctionCallCode(
         if context.needsCleanup(arg_name):
             context.removeCleanupTempName(arg_name)
         else:
-            emit("Py_INCREF( %s );" % arg_name)
+            emit("Py_INCREF(%s);" % arg_name)
 
     if arg_names:
         emit(
             """
 {
     PyObject *dir_call_args[] = {%s};
-    %s = %s( dir_call_args%s%s );
+    %s = %s(dir_call_args%s%s);
 }"""
             % (
                 ", ".join(str(arg_name) for arg_name in arg_names),
@@ -389,7 +416,7 @@ def getDirectFunctionCallCode(
         )
     else:
         emit(
-            "%s = %s( NULL%s%s );"
+            "%s = %s(NULL%s%s);"
             % (
                 to_name,
                 function_identifier,
@@ -449,7 +476,7 @@ def setupFunctionLocalVariables(
             variable_declaration = context.variable_storage.addVariableDeclarationTop(
                 variable_c_type.c_type,
                 variable_code_name,
-                variable_c_type.getInitValue("python_pars[ %d ]" % count),
+                variable_c_type.getInitValue("python_pars[%d]" % count),
             )
 
             context.setVariableType(variable, variable_declaration)
@@ -503,9 +530,19 @@ def finalizeFunctionLocalVariables(context):
     # TODO: Many times this will not be necessary.
     for locals_declaration in context.getLocalsDictNames():
         function_cleanup.append(
-            "Py_XDECREF( %(locals_dict)s );\n" % {"locals_dict": locals_declaration}
+            "Py_XDECREF(%(locals_dict)s);\n" % {"locals_dict": locals_declaration}
         )
 
+    # Automatic variable releases if any.
+    for variable in context.getOwner().getFunctionVariablesWithAutoReleases():
+        variable_declaration = getLocalVariableDeclaration(
+            context=context,
+            variable=variable,
+            variable_trace=None,  # TODO: See other uses of None.
+        )
+        function_cleanup.append("CHECK_OBJECT(%s);" % variable_declaration)
+        function_cleanup.append("Py_DECREF(%s);" % variable_declaration)
+
     return function_cleanup
 
 
@@ -535,7 +572,7 @@ def getFunctionCode(
             needs_exception_exit=needs_exception_exit,
         )
     except Exception:
-        warning("Problem creating function code %r." % function_identifier)
+        general.warning("Problem creating function code %r." % function_identifier)
         raise
 
 
@@ -583,16 +620,19 @@ def _getFunctionCode(
     emit = SourceCodeCollector()
 
     getMustNotGetHereCode(
-        reason="Return statement must have exited already.", context=context, emit=emit
+        reason="Return statement must have exited already.", emit=emit
     )
 
     function_exit = indented(emit.codes) + "\n\n"
     del emit
 
     if needs_exception_exit:
-        exception_type, exception_value, exception_tb, _exception_lineno = (
-            context.variable_storage.getExceptionVariableDescriptions()
-        )
+        (
+            exception_type,
+            exception_value,
+            exception_tb,
+            _exception_lineno,
+        ) = context.variable_storage.getExceptionVariableDescriptions()
 
         function_exit += template_function_exception_exit % {
             "function_cleanup": indented(function_cleanup),
@@ -611,7 +651,7 @@ def _getFunctionCode(
     else:
         parameter_objects_decl = []
 
-    parameter_objects_decl += ["PyObject **python_pars"]
+    parameter_objects_decl.append("PyObject **python_pars")
 
     if context.isForDirectCall():
         for closure_variable in closure_variables:
@@ -733,9 +773,7 @@ def generateFunctionOutlineCode(to_name, expression, emit, context):
         context.addCleanupTempName(return_value_name)
 
         getMustNotGetHereCode(
-            reason="Return statement must have exited already.",
-            context=context,
-            emit=emit,
+            reason="Return statement must have exited already.", emit=emit
         )
 
         if exception_target is not None:
