@@ -1,4 +1,4 @@
-#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2020, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -19,6 +19,7 @@
 
 """
 
+from nuitka.codegen.ErrorCodes import getReleaseCode
 
 from .CTypeBases import CTypeBase
 
@@ -26,13 +27,14 @@ from .CTypeBases import CTypeBase
 class CTypeNuitkaBoolEnum(CTypeBase):
     c_type = "nuitka_bool"
 
+    helper_code = "NBOOL"
+
     @classmethod
     def emitVariableAssignCode(
         cls, value_name, needs_release, tmp_name, ref_count, in_place, emit, context
     ):
 
         assert not in_place
-        assert not ref_count
 
         if tmp_name.c_type == "nuitka_bool":
             emit("%s = %s;" % (value_name, tmp_name))
@@ -46,6 +48,16 @@ class CTypeNuitkaBoolEnum(CTypeBase):
                 to_name=value_name, condition=test_code, emit=emit
             )
 
+            # TODO: Refcount and context needs release are redundant.
+            if ref_count:
+                getReleaseCode(tmp_name, emit, context)
+
+    @classmethod
+    def emitAssignmentCodeToNuitkaIntOrLong(
+        cls, to_name, value_name, needs_check, emit, context
+    ):
+        assert False, to_name
+
     @classmethod
     def getLocalVariableInitTestCode(cls, value_name, inverted):
         return "%s %s NUITKA_BOOL_UNASSIGNED" % (value_name, "==" if inverted else "!=")
@@ -113,3 +125,7 @@ class CTypeNuitkaBoolEnum(CTypeBase):
             "%(to_name)s = (%(condition)s) ? NUITKA_BOOL_TRUE : NUITKA_BOOL_FALSE;"
             % {"to_name": to_name, "condition": condition}
         )
+
+    @classmethod
+    def getExceptionCheckCondition(cls, value_name):
+        return "%s == NUITKA_BOOL_EXCEPTION" % value_name
