@@ -1,4 +1,4 @@
-#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2020, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -75,6 +75,20 @@ class CPythonPyObjectPtrBase(CTypeBase):
 
         emit(template % {"identifier": value_name, "tmp_name": tmp_name})
 
+    @classmethod
+    def emitAssignmentCodeToNuitkaIntOrLong(
+        cls, to_name, value_name, needs_check, emit, context
+    ):
+        to_type = to_name.getCType()
+
+        to_type.emitVariantAssignmentCode(
+            int_name=to_name,
+            value_name=value_name,
+            int_value=None,
+            emit=emit,
+            context=context,
+        )
+
     @classmethod
     def getTruthCheckCode(cls, value_name):
         return "CHECK_IF_TRUE(%s)" % value_name
@@ -131,6 +145,8 @@ class CPythonPyObjectPtrBase(CTypeBase):
 class CTypePyObjectPtr(CPythonPyObjectPtrBase):
     c_type = "PyObject *"
 
+    helper_code = "OBJECT"
+
     @classmethod
     def getInitValue(cls, init_from):
         if init_from is None:
@@ -203,6 +219,10 @@ class CTypePyObjectPtr(CPythonPyObjectPtrBase):
         else:
             assert False, to_name.c_type
 
+    @classmethod
+    def getExceptionCheckCondition(cls, value_name):
+        return "%s == NULL" % value_name
+
 
 class CTypePyObjectPtrPtr(CPythonPyObjectPtrBase):
     c_type = "PyObject **"
