@@ -1,4 +1,4 @@
-#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2020, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -28,8 +28,8 @@ struct %(function_identifier)s_locals {
 %(function_local_types)s
 };
 
-static PyObject *%(function_identifier)s_context( struct Nuitka_AsyncgenObject *asyncgen, PyObject *yield_return_value ) {
-    CHECK_OBJECT((PyObject *)asyncgen);
+static PyObject *%(function_identifier)s_context(struct Nuitka_AsyncgenObject *asyncgen, PyObject *yield_return_value) {
+    CHECK_OBJECT(asyncgen);
     assert(Nuitka_Asyncgen_Check((PyObject *)asyncgen));
 
     // Heap access if used.
@@ -65,9 +65,9 @@ template_make_asyncgen = """\
 %(closure_copy)s
 """
 
+# TODO: For functions NUITKA_CANNOT_GET_HERE is injected by composing code.
 template_asyncgen_exception_exit = """\
-    // Return statement must be present.
-    NUITKA_CANNOT_GET_HERE(%(function_identifier)s);
+    NUITKA_CANNOT_GET_HERE("return must be present");
 
     function_exception_exit:
 %(function_cleanup)s\
@@ -77,8 +77,7 @@ template_asyncgen_exception_exit = """\
 """
 
 template_asyncgen_noexception_exit = """\
-    // Return statement must be present.
-    NUITKA_CANNOT_GET_HERE(%(function_identifier)s);
+    NUITKA_CANNOT_GET_HERE("return must be present");
 
 %(function_cleanup)s\
 
