@@ -1,4 +1,4 @@
-#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2020, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -93,22 +93,6 @@ static void createModuleCodeObjects(void) {
 // The module function definitions.
 %(module_functions_code)s
 
-
-#if PYTHON_VERSION >= 300
-static struct PyModuleDef mdef_%(module_identifier)s =
-{
-    PyModuleDef_HEAD_INIT,
-    NULL,                /* m_name, filled later */
-    NULL,                /* m_doc */
-    -1,                  /* m_size */
-    NULL,                /* m_methods */
-    NULL,                /* m_reload */
-    NULL,                /* m_traverse */
-    NULL,                /* m_clear */
-    NULL,                /* m_free */
-  };
-#endif
-
 extern PyObject *const_str_plain___compiled__;
 
 extern PyObject *const_str_plain___package__;
@@ -130,12 +114,6 @@ extern void _initCompiledGeneratorType();
 extern void _initCompiledFunctionType();
 extern void _initCompiledMethodType();
 extern void _initCompiledFrameType();
-#if PYTHON_VERSION >= 350
-extern void _initCompiledCoroutineTypes();
-#endif
-#if PYTHON_VERSION >= 360
-extern void _initCompiledAsyncgenTypes();
-#endif
 
 extern PyTypeObject Nuitka_Loader_Type;
 
@@ -161,7 +139,7 @@ static PyObject *_reduce_compiled_function(PyObject *self, PyObject *args, PyObj
     }
 
     if (Nuitka_Function_Check(func) == false) {
-        PyErr_Format(PyExc_TypeError, "not a compiled function");
+        SET_CURRENT_EXCEPTION_TYPE0_STR(PyExc_TypeError, "not a compiled function");
         return NULL;
     }
 
@@ -180,7 +158,7 @@ static PyObject *_reduce_compiled_function(PyObject *self, PyObject *args, PyObj
     }
 
     if (*current == NULL) {
-        PyErr_Format(PyExc_TypeError, "Cannot find compiled function in module.");
+        SET_CURRENT_EXCEPTION_TYPE0_STR(PyExc_TypeError, "Cannot find compiled function in module.");
         return NULL;
     }
 
@@ -236,7 +214,7 @@ static PyObject *_create_compiled_function(PyObject *self, PyObject *args, PyObj
     }
 
     if (offset > sizeof(functable_%(module_identifier)s) || offset < 0) {
-        PyErr_Format(PyExc_TypeError, "Wrong offset for compiled function.");
+        SET_CURRENT_EXCEPTION_TYPE0_STR(PyExc_TypeError, "Wrong offset for compiled function.");
         return NULL;
     }
 
@@ -296,7 +274,9 @@ static PyMethodDef _method_def_create_compiled_function = {
 #endif
 
 // Internal entry point for module code.
-PyObject *modulecode_%(module_identifier)s(char const *module_full_name) {
+PyObject *modulecode_%(module_identifier)s(PyObject *module) {
+    module_%(module_identifier)s = module;
+
 #if defined(_NUITKA_EXE) || PYTHON_VERSION >= 300
     static bool _init_done = false;
 
@@ -328,12 +308,6 @@ PyObject *modulecode_%(module_identifier)s(char const *module_full_name) {
     _initCompiledFunctionType();
     _initCompiledMethodType();
     _initCompiledFrameType();
-#if PYTHON_VERSION >= 350
-    _initCompiledCoroutineTypes();
-#endif
-#if PYTHON_VERSION >= 360
-    _initCompiledAsyncgenTypes();
-#endif
 
 #if PYTHON_VERSION < 300
     _initSlotCompare();
@@ -376,21 +350,6 @@ PyObject *modulecode_%(module_identifier)s(char const *module_full_name) {
     // set at this time, as it could not contain NUL characters this way, they
     // are instead set in early module code.  No "self" for modules, we have no
     // use for it.
-#if PYTHON_VERSION < 300
-    module_%(module_identifier)s = Py_InitModule4(
-        module_full_name,        // Module Name
-        NULL,                    // No methods initially, all are added
-                                 // dynamically in actual module code only.
-        NULL,                    // No "__doc__" is initially set, as it could
-                                 // not contain NUL this way, added early in
-                                 // actual code.
-        NULL,                    // No self for modules, we don't use it.
-        PYTHON_API_VERSION
-    );
-#else
-    mdef_%(module_identifier)s.m_name = module_full_name;
-    module_%(module_identifier)s = PyModule_Create(&mdef_%(module_identifier)s);
-#endif
 
     moduledict_%(module_identifier)s = MODULE_DICT(module_%(module_identifier)s);
 
@@ -404,8 +363,8 @@ PyObject *modulecode_%(module_identifier)s(char const *module_full_name) {
         }
         PyObject_SetAttrString((PyObject *)builtin_module, "compiled_function_tables", function_tables);
         PyObject *funcs = PyTuple_New(2);
-        PyTuple_SetItem(funcs, 0, PyCFunction_New(&_method_def_reduce_compiled_function, NULL));
-        PyTuple_SetItem(funcs, 1, PyCFunction_New(&_method_def_create_compiled_function, NULL));
+        PyTuple_SET_ITEM(funcs, 0, PyCFunction_New(&_method_def_reduce_compiled_function, NULL));
+        PyTuple_SET_ITEM(funcs, 1, PyCFunction_New(&_method_def_create_compiled_function, NULL));
         PyDict_SetItemString(function_tables, module_full_name, funcs);
     }
 #endif
@@ -467,15 +426,6 @@ PyObject *modulecode_%(module_identifier)s(char const *module_full_name) {
 
     CHECK_OBJECT(module_%(module_identifier)s);
 
-// Seems to work for Python2.7 out of the box, but for Python3, the module
-// doesn't automatically enter "sys.modules", so do it manually.
-#if PYTHON_VERSION >= 300
-    {
-        int r = PyDict_SetItemString(PyImport_GetModuleDict(), module_full_name, module_%(module_identifier)s);
-        assert(r != -1);
-    }
-#endif
-
     // For deep importing of a module we need to have "__builtins__", so we set
     // it ourselves in the same way than CPython does. Note: This must be done
     // before the frame object is allocated, or else it may fail.
@@ -550,7 +500,7 @@ PyObject *modulecode_%(module_identifier)s(char const *module_full_name) {
 
 template_module_external_entry_point = r"""
 
-/* Visibility definitions to make the DLL entry poinz exported */
+/* Visibility definitions to make the DLL entry point exported */
 #if defined(__GNUC__)
 
 #if PYTHON_VERSION < 300
@@ -579,6 +529,21 @@ template_module_external_entry_point = r"""
 #define MOD_INIT_DECL(name) NUITKA_MODULE_INIT_FUNCTION PyInit_##name(void)
 #endif
 
+#if PYTHON_VERSION >= 300
+static struct PyModuleDef mdef_%(module_identifier)s = {
+    PyModuleDef_HEAD_INIT,
+    NULL,                /* m_name, filled later */
+    NULL,                /* m_doc */
+    -1,                  /* m_size */
+    NULL,                /* m_methods */
+    NULL,                /* m_reload */
+    NULL,                /* m_traverse */
+    NULL,                /* m_clear */
+    NULL,                /* m_free */
+};
+
+#endif
+
 /* The exported interface to CPython. On import of the module, this function
  * gets called. It has to have an exact function name, in cases it's a shared
  * library export. This is hidden behind the MOD_INIT_DECL macro.
@@ -590,9 +555,30 @@ MOD_INIT_DECL(%(module_identifier)s) {
     }
 
 #if PYTHON_VERSION < 300
-    modulecode_%(module_identifier)s(module_full_name);
+    PyObject *module = Py_InitModule4(
+        module_full_name,        // Module Name
+        NULL,                    // No methods initially, all are added
+                                 // dynamically in actual module code only.
+        NULL,                    // No "__doc__" is initially set, as it could
+                                 // not contain NUL this way, added early in
+                                 // actual code.
+        NULL,                    // No self for modules, we don't use it.
+        PYTHON_API_VERSION
+    );
 #else
-    PyObject *result = modulecode_%(module_identifier)s(module_full_name);
+    mdef_%(module_identifier)s.m_name = module_full_name;
+    PyObject *module = PyModule_Create(&mdef_%(module_identifier)s);
+    CHECK_OBJECT(module);
+
+    PyObject *module_name = PyUnicode_FromString(module_full_name);
+    int res = PyDict_SetItem(PyImport_GetModuleDict(), module_name, module);
+    assert(res != -1);
+#endif
+
+#if PYTHON_VERSION < 300
+    modulecode_%(module_identifier)s(module);
+#else
+    PyObject *result = modulecode_%(module_identifier)s(module);
     return result;
 #endif
 }
