@@ -1,4 +1,4 @@
-#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2020, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -42,7 +42,10 @@ from nuitka.importing.StandardLibrary import (
     getStandardLibraryPaths,
     isStandardLibraryPath,
 )
-from nuitka.nodes.ModuleNodes import PythonShlibModule, makeUncompiledPythonModule
+from nuitka.nodes.ModuleNodes import (
+    PythonShlibModule,
+    makeUncompiledPythonModule,
+)
 from nuitka.plugins.Plugins import Plugins
 from nuitka.PythonVersions import python_version
 from nuitka.tree.SourceReading import readSourceCodeFromFilename
@@ -52,6 +55,7 @@ from nuitka.utils.Execution import withEnvironmentPathAdded
 from nuitka.utils.FileOperations import (
     areSamePaths,
     deleteFile,
+    getExternalUsePath,
     getFileContentByLine,
     getFileContents,
     getSubDirectories,
@@ -60,7 +64,9 @@ from nuitka.utils.FileOperations import (
     makePath,
     withFileLock,
 )
+from nuitka.utils.ModuleNames import ModuleName
 from nuitka.utils.SharedLibraries import (
+    callInstallNameTool,
     getPEFileInformation,
     getWindowsDLLVersion,
     removeSxsFromDLL,
@@ -120,7 +126,7 @@ def _detectedSourceFile(filename, module_name, result, user_provided, technical)
     if module_name == "collections.abc":
         _detectedSourceFile(
             filename=filename,
-            module_name="_collections_abc",
+            module_name=ModuleName("_collections_abc"),
             result=result,
             user_provided=user_provided,
             technical=technical,
@@ -182,24 +188,15 @@ def _detectedShlibFile(filename, module_name):
     if module_name == "__main__":
         return
 
+    # Cyclic dependency
     from nuitka import ModuleRegistry
 
     if ModuleRegistry.hasRootModule(module_name):
         return
 
-    parts = module_name.split(".")
-    if len(parts) == 1:
-        package_name = None
-        name = module_name
-    else:
-        package_name = ".".join(parts[:-1])
-        name = parts[-1]
-
     source_ref = SourceCodeReferences.fromFilename(filename=filename)
 
-    shlib_module = PythonShlibModule(
-        name=name, package_name=package_name, source_ref=source_ref
-    )
+    shlib_module = PythonShlibModule(module_name=module_name, source_ref=source_ref)
 
     ModuleRegistry.addRootModule(shlib_module)
     ImportCache.addImportedModule(shlib_module)
@@ -279,6 +276,8 @@ def _detectImports(command, user_provided, technical):
             if python_version >= 300:
                 module_name = module_name.decode("utf-8")
 
+            module_name = ModuleName(module_name)
+
             if origin == b"precompiled":
                 # This is a ".pyc" file that was imported, even before we have a
                 # chance to do anything, we need to preserve it.
@@ -308,7 +307,7 @@ def _detectImports(command, user_provided, technical):
                     # clashes with "decimal" proper
                     if python_version >= 300:
                         if module_name == "decimal":
-                            module_name = "_decimal"
+                            module_name = ModuleName("_decimal")
 
                     detections.append((module_name, 2, "shlib", filename))
             elif origin == b"dynamically":
@@ -406,6 +405,11 @@ def scanStandardLibraryPath(stdlib_dir):
             if "test" in dirs:
                 dirs.remove("test")
 
+        if import_path == "distutils.command":
+            # Misbehaving and crashing while importing the world.
+            if "bdist_conda.py" in filenames:
+                filenames.remove("bdist_conda.py")
+
         if import_path in ("lib2to3", "json", "distutils"):
             if "tests" in dirs:
                 dirs.remove("tests")
@@ -447,7 +451,7 @@ def scanStandardLibraryPath(stdlib_dir):
                 yield import_path + "." + dirname
 
 
-def detectEarlyImports():
+def _detectEarlyImports():
     encoding_names = [
         filename[:-3]
         for _path, filename in listDir(
@@ -520,6 +524,9 @@ for imp in imports:
         __import__(imp)
     except (ImportError, SyntaxError):
         failed.add(imp)
+    except Exception:
+        sys.stderr("PROBLEM with '%%s'\\n" %% imp)
+        raise
 
     for fail in failed:
         if fail in sys.modules:
@@ -543,6 +550,14 @@ for imp in imports:
     return result
 
 
+def detectEarlyImports():
+    # Cyclic dependency
+    from nuitka import ModuleRegistry
+
+    for module in _detectEarlyImports():
+        ModuleRegistry.addUncompiledModule(module)
+
+
 _detected_python_rpath = None
 
 ldd_result_cache = {}
@@ -668,7 +683,7 @@ def _detectBinaryPathDLLsPosix(dll_filename):
     return sub_result
 
 
-def _detectBinaryPathDLLsMacOS(original_dir, binary_filename):
+def _detectBinaryPathDLLsMacOS(original_dir, binary_filename, keep_unresolved):
     result = set()
 
     process = subprocess.Popen(
@@ -680,7 +695,7 @@ def _detectBinaryPathDLLsMacOS(original_dir, binary_filename):
     stdout, _stderr = process.communicate()
     system_paths = (b"/usr/lib/", b"/System/Library/Frameworks/")
 
-    for line in stdout.split(b"\n")[2:]:
+    for line in stdout.split(b"\n")[1:]:
         if not line:
             continue
 
@@ -694,14 +709,70 @@ def _detectBinaryPathDLLsMacOS(original_dir, binary_filename):
             if python_version >= 300:
                 filename = filename.decode("utf-8")
 
-            if filename.startswith("@rpath/"):
-                filename = os.path.join(original_dir, filename[7:])
-            elif filename.startswith("@loader_path/"):
-                filename = os.path.join(original_dir, filename[13:])
-
-            # print "adding", filename
+            # print("adding", filename)
             result.add(filename)
 
+    resolved_result = _resolveBinaryPathDLLsMacOS(
+        original_dir, binary_filename, result, keep_unresolved
+    )
+    return resolved_result
+
+
+def _resolveBinaryPathDLLsMacOS(original_dir, binary_filename, paths, keep_unresolved):
+    if keep_unresolved:
+        result = {}
+    else:
+        result = set()
+
+    rpaths = _detectBinaryRPathsMacOS(original_dir, binary_filename)
+
+    for path in paths:
+        if path.startswith("@rpath/"):
+            for rpath in rpaths:
+                if os.path.isfile(os.path.join(rpath, path[7:])):
+                    resolved_path = os.path.join(rpath, path[7:])
+                    break
+            else:
+                resolved_path = os.path.join(original_dir, path[7:])
+
+        elif path.startswith("@loader_path/"):
+            resolved_path = os.path.join(original_dir, path[13:])
+        else:
+            resolved_path = path
+        if keep_unresolved:
+            result.update({resolved_path: path})
+        else:
+            result.add(resolved_path)
+    return result
+
+
+def _detectBinaryRPathsMacOS(original_dir, binary_filename):
+    result = set()
+
+    process = subprocess.Popen(
+        args=["otool", "-l", binary_filename],
+        stdout=subprocess.PIPE,
+        stderr=subprocess.PIPE,
+    )
+
+    stdout, _stderr = process.communicate()
+
+    lines = stdout.split(b"\n")
+
+    for i, o in enumerate(lines):
+        if o.endswith(b"cmd LC_RPATH"):
+            line = lines[i + 2]
+            if python_version >= 300:
+                line = line.decode("utf-8")
+
+            line = line.split("path ")[1]
+            line = line.split(" (offset")[0]
+            if line.startswith("@loader_path"):
+                line = os.path.join(original_dir, line[13:])
+            elif line.startswith("@executable_path"):
+                continue
+            result.add(line)
+
     return result
 
 
@@ -806,10 +877,23 @@ def _parseDependsExeOutput(filename, result):
     _parseDependsExeOutput2(getFileContentByLine(filename), result)
 
 
+def _getPyWin32Dir():
+    for path_element in sys.path:
+        if not path_element:
+            continue
+
+        candidate = os.path.join(path_element, "pywin32_system32")
+
+        if os.path.isdir(candidate):
+            return candidate
+
+
 _scan_dir_cache = {}
 
 
 def getScanDirectories(package_name, original_dir):
+    # Many cases, pylint: disable=too-many-branches
+
     cache_key = package_name, original_dir
 
     if cache_key in _scan_dir_cache:
@@ -830,6 +914,16 @@ def getScanDirectories(package_name, original_dir):
         scan_dirs.append(original_dir)
         scan_dirs.extend(getSubDirectories(original_dir))
 
+    if (
+        Utils.isWin32Windows()
+        and package_name is not None
+        and package_name.isBelowNamespace("win32com")
+    ):
+        pywin32_dir = _getPyWin32Dir()
+
+        if pywin32_dir is not None:
+            scan_dirs.append(pywin32_dir)
+
     for path_dir in os.environ["PATH"].split(";"):
         if not os.path.isdir(path_dir):
             continue
@@ -857,7 +951,7 @@ def getScanDirectories(package_name, original_dir):
         if not any(entry[1].lower().endswith(".dll") for entry in listDir(scan_dir)):
             continue
 
-        result.append(scan_dir)
+        result.append(os.path.realpath(scan_dir))
 
     _scan_dir_cache[cache_key] = result
     return result
@@ -918,9 +1012,9 @@ def detectBinaryPathDLLsWindowsDependencyWalker(
         with open(dwp_filename, "w") as dwp_file:
             dwp_file.write(
                 """\
-    %(scan_dirs)s
-    SxS
-    """
+%(scan_dirs)s
+SxS
+"""
                 % {
                     "scan_dirs": "\n".join(
                         "UserDir %s" % dirname for dirname in scan_dirs
@@ -939,7 +1033,8 @@ def detectBinaryPathDLLsWindowsDependencyWalker(
             "-pa1",
             "-ps1",
             binary_filename,
-        )
+        ),
+        cwd=getExternalUsePath(os.getcwd()),
     )
 
     # TODO: Exit code should be checked.
@@ -1114,7 +1209,10 @@ def detectBinaryDLLs(
         "otool" (macOS) the list of used DLLs is retrieved.
     """
 
-    if Utils.getOS() in ("Linux", "NetBSD", "FreeBSD") or Utils.isPosixWindows():
+    if (
+        Utils.getOS() in ("Linux", "NetBSD", "FreeBSD", "OpenBSD")
+        or Utils.isPosixWindows()
+    ):
         return _detectBinaryPathDLLsPosix(dll_filename=original_filename)
     elif Utils.isWin32Windows() and Options.getWindowsDependencyTool() == "pefile":
         with TimerReport(
@@ -1146,6 +1244,7 @@ def detectBinaryDLLs(
         return _detectBinaryPathDLLsMacOS(
             original_dir=os.path.dirname(original_filename),
             binary_filename=original_filename,
+            keep_unresolved=False,
         )
     else:
         # Support your platform above.
@@ -1215,28 +1314,28 @@ manually."""
     return result
 
 
-def fixupBinaryDLLPaths(binary_filename, is_exe, dll_map):
+def fixupBinaryDLLPathsMacOS(binary_filename, dll_map, original_location):
     """ For macOS, the binary needs to be told to use relative DLL paths """
 
     # There may be nothing to do, in case there are no DLLs.
     if not dll_map:
         return
 
-    command = ["install_name_tool"]
-
-    for original_path, dist_path in dll_map:
-        command += ["-change", original_path, "@executable_path/" + dist_path]
-
-    os.chmod(binary_filename, int("644", 8))
-    command.append(binary_filename)
-    process = subprocess.Popen(
-        args=command, stdout=subprocess.PIPE, stderr=subprocess.PIPE
+    rpath_map = _detectBinaryPathDLLsMacOS(
+        original_dir=os.path.dirname(original_location),
+        binary_filename=original_location,
+        keep_unresolved=True,
     )
-    _stdout, stderr = process.communicate()
-    os.chmod(binary_filename, int("755" if is_exe else "444", 8))
+    for i, o in enumerate(dll_map):
+        dll_map[i] = (rpath_map.get(o[0], o[0]), o[1])
 
-    # Don't let errors here go unnoticed.
-    assert process.returncode == 0, stderr
+    callInstallNameTool(
+        filename=binary_filename,
+        mapping=(
+            (original_path, "@executable_path/" + dist_path)
+            for (original_path, dist_path) in dll_map
+        ),
+    )
 
 
 def getSharedLibraryRPATH(filename):
@@ -1408,7 +1507,7 @@ different from
         dll_map.append((dll_filename, dll_name))
 
         if Options.isShowInclusion():
-            info(
+            Tracing.general.info(
                 "Included used shared library '%s' (used by %s)."
                 % (dll_filename, ", ".join(sources))
             )
@@ -1417,17 +1516,17 @@ different from
         # For macOS, the binary and the DLLs needs to be changed to reflect
         # the relative DLL location in the ".dist" folder.
         for standalone_entry_point in standalone_entry_points:
-            fixupBinaryDLLPaths(
+            fixupBinaryDLLPathsMacOS(
                 binary_filename=standalone_entry_point[1],
-                is_exe=standalone_entry_point is standalone_entry_points[0],
                 dll_map=dll_map,
+                original_location=standalone_entry_point[0],
             )
 
-        for _original_path, dll_filename in dll_map:
-            fixupBinaryDLLPaths(
+        for original_path, dll_filename in dll_map:
+            fixupBinaryDLLPathsMacOS(
                 binary_filename=os.path.join(dist_dir, dll_filename),
-                is_exe=False,
                 dll_map=dll_map,
+                original_location=original_path,
             )
 
     if Utils.getOS() == "Linux":
@@ -1448,31 +1547,36 @@ different from
                 removeSxsFromDLL(os.path.join(dist_dir, dll_filename))
 
 
-def copyDataFiles(dist_dir, data_files):
+def copyDataFiles(dist_dir):
     """ Copy the data files needed for standalone distribution.
 
     Args:
         dist_dir: The distribution folder under creation
-        data_files:
-            Tuple of pairs describing (source, dest) or (func, dest) that
-            should be copied.
     Notes:
         This is for data files only, not DLLs or even extension modules,
         those must be registered as entry points, and would not go through
         necessary handling if provided like this.
     """
-    for source_desc, target_filename in data_files:
-        target_filename = os.path.join(dist_dir, target_filename)
-        assert isPathBelow(dist_dir, target_filename)
 
-        makePath(os.path.dirname(target_filename))
+    # Cyclic dependency
+    from nuitka import ModuleRegistry
 
-        if inspect.isfunction(source_desc):
-            content = source_desc(target_filename)
+    for module in ModuleRegistry.getDoneModules():
+        for _plugin_name, (source_desc, target_filename) in Plugins.considerDataFiles(
+            module
+        ):
+            target_filename = os.path.join(dist_dir, target_filename)
+            assert isPathBelow(dist_dir, target_filename)
 
-            with open(
-                target_filename, "wb" if type(content) is bytes else "w"
-            ) as output:
-                output.write(content)
-        else:
-            shutil.copy2(source_desc, target_filename)
+            makePath(os.path.dirname(target_filename))
+
+            if inspect.isfunction(source_desc):
+                content = source_desc(target_filename)
+
+                if content is not None:  # support creation of empty directories
+                    with open(
+                        target_filename, "wb" if type(content) is bytes else "w"
+                    ) as output:
+                        output.write(content)
+            else:
+                shutil.copy2(source_desc, target_filename)
