@@ -1,4 +1,4 @@
-#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2020, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -22,22 +22,23 @@ whose implementation lives here. The creation itself also lives here.
 
 """
 
-from .ExpressionBases import ExpressionChildrenHavingBase
+from .ExpressionBases import ExpressionChildHavingBase
 from .FunctionNodes import ExpressionFunctionEntryPointBase
 
 
-class ExpressionMakeAsyncgenObject(ExpressionChildrenHavingBase):
+class ExpressionMakeAsyncgenObject(ExpressionChildHavingBase):
     kind = "EXPRESSION_MAKE_ASYNCGEN_OBJECT"
 
-    named_children = ("asyncgen_ref",)
+    named_child = "asyncgen_ref"
+    getAsyncgenRef = ExpressionChildHavingBase.childGetter("asyncgen_ref")
 
-    getAsyncgenRef = ExpressionChildrenHavingBase.childGetter("asyncgen_ref")
+    __slots__ = ("variable_closure_traces",)
 
     def __init__(self, asyncgen_ref, source_ref):
         assert asyncgen_ref.getFunctionBody().isExpressionAsyncgenObjectBody()
 
-        ExpressionChildrenHavingBase.__init__(
-            self, values={"asyncgen_ref": asyncgen_ref}, source_ref=source_ref
+        ExpressionChildHavingBase.__init__(
+            self, value=asyncgen_ref, source_ref=source_ref
         )
 
         self.variable_closure_traces = []
@@ -74,7 +75,7 @@ class ExpressionAsyncgenObjectBody(ExpressionFunctionEntryPointBase):
 
     qualname_setup = None
 
-    def __init__(self, provider, name, code_object, flags, source_ref):
+    def __init__(self, provider, name, code_object, flags, auto_release, source_ref):
         ExpressionFunctionEntryPointBase.__init__(
             self,
             provider=provider,
@@ -82,6 +83,7 @@ class ExpressionAsyncgenObjectBody(ExpressionFunctionEntryPointBase):
             code_object=code_object,
             code_prefix="asyncgen",
             flags=flags,
+            auto_release=auto_release,
             source_ref=source_ref,
         )
 
