@@ -1,4 +1,4 @@
-#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2020, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -27,7 +27,7 @@ good.
 from nuitka.specs import BuiltinParameterSpecs
 
 from .ExpressionBases import ExpressionBuiltinSingleArgBase
-from .shapes.BuiltinTypeShapes import ShapeTypeIntOrLong
+from .shapes.BuiltinTypeShapes import tshape_int_or_long
 
 
 class ExpressionBuiltinLen(ExpressionBuiltinSingleArgBase):
@@ -49,7 +49,7 @@ class ExpressionBuiltinLen(ExpressionBuiltinSingleArgBase):
         )
 
     def getTypeShape(self):
-        return ShapeTypeIntOrLong
+        return tshape_int_or_long
 
     def mayRaiseException(self, exception_type):
         value = self.getValue()
