@@ -1,4 +1,4 @@
-#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2020, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -25,13 +25,20 @@ There will be a method "computeExpressionCall" to aid predicting them in other
 nodes.
 """
 
-from .ExpressionBases import ExpressionChildrenHavingBase
+from .ExpressionBases import (
+    ExpressionChildHavingBase,
+    ExpressionChildrenHavingBase,
+)
 
 
 class ExpressionCall(ExpressionChildrenHavingBase):
     kind = "EXPRESSION_CALL"
 
     named_children = ("called", "args", "kw")
+    getCalled = ExpressionChildrenHavingBase.childGetter("called")
+    setCalled = ExpressionChildrenHavingBase.childSetter("called")
+    getCallArgs = ExpressionChildrenHavingBase.childGetter("args")
+    getCallKw = ExpressionChildrenHavingBase.childGetter("kw")
 
     def __init__(self, called, args, kw, source_ref):
         assert called.isExpression()
@@ -44,11 +51,6 @@ class ExpressionCall(ExpressionChildrenHavingBase):
             source_ref=source_ref,
         )
 
-    getCalled = ExpressionChildrenHavingBase.childGetter("called")
-    setCalled = ExpressionChildrenHavingBase.childSetter("called")
-    getCallArgs = ExpressionChildrenHavingBase.childGetter("args")
-    getCallKw = ExpressionChildrenHavingBase.childGetter("kw")
-
     def isExpressionCall(self):
         return True
 
@@ -73,6 +75,9 @@ class ExpressionCallNoKeywords(ExpressionChildrenHavingBase):
     kind = "EXPRESSION_CALL_NO_KEYWORDS"
 
     named_children = ("called", "args")
+    getCalled = ExpressionChildrenHavingBase.childGetter("called")
+    setCalled = ExpressionChildrenHavingBase.childSetter("called")
+    getCallArgs = ExpressionChildrenHavingBase.childGetter("args")
 
     def __init__(self, called, args, source_ref):
         assert called.isExpression()
@@ -82,10 +87,6 @@ class ExpressionCallNoKeywords(ExpressionChildrenHavingBase):
             self, values={"called": called, "args": args}, source_ref=source_ref
         )
 
-    getCalled = ExpressionChildrenHavingBase.childGetter("called")
-    setCalled = ExpressionChildrenHavingBase.childSetter("called")
-    getCallArgs = ExpressionChildrenHavingBase.childGetter("args")
-
     def computeExpression(self, trace_collection):
         return self.getCalled().computeExpressionCall(
             call_node=self,
@@ -111,6 +112,9 @@ class ExpressionCallKeywordsOnly(ExpressionChildrenHavingBase):
     kind = "EXPRESSION_CALL_KEYWORDS_ONLY"
 
     named_children = ("called", "kw")
+    getCalled = ExpressionChildrenHavingBase.childGetter("called")
+    setCalled = ExpressionChildrenHavingBase.childSetter("called")
+    getCallKw = ExpressionChildrenHavingBase.childGetter("kw")
 
     def __init__(self, called, kw, source_ref):
         assert called.isExpression()
@@ -120,10 +124,6 @@ class ExpressionCallKeywordsOnly(ExpressionChildrenHavingBase):
             self, values={"called": called, "kw": kw}, source_ref=source_ref
         )
 
-    getCalled = ExpressionChildrenHavingBase.childGetter("called")
-    setCalled = ExpressionChildrenHavingBase.childSetter("called")
-    getCallKw = ExpressionChildrenHavingBase.childGetter("kw")
-
     def computeExpression(self, trace_collection):
         called = self.getCalled()
 
@@ -147,20 +147,17 @@ class ExpressionCallKeywordsOnly(ExpressionChildrenHavingBase):
         return kw.extractSideEffects()
 
 
-class ExpressionCallEmpty(ExpressionChildrenHavingBase):
+class ExpressionCallEmpty(ExpressionChildHavingBase):
     kind = "EXPRESSION_CALL_EMPTY"
 
-    named_children = ("called",)
+    named_child = "called"
+    getCalled = ExpressionChildHavingBase.childGetter("called")
+    setCalled = ExpressionChildHavingBase.childSetter("called")
 
     def __init__(self, called, source_ref):
         assert called.isExpression()
 
-        ExpressionChildrenHavingBase.__init__(
-            self, values={"called": called}, source_ref=source_ref
-        )
-
-    getCalled = ExpressionChildrenHavingBase.childGetter("called")
-    setCalled = ExpressionChildrenHavingBase.childSetter("called")
+        ExpressionChildHavingBase.__init__(self, value=called, source_ref=source_ref)
 
     def computeExpression(self, trace_collection):
         called = self.getCalled()
