@@ -1,4 +1,4 @@
-#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2020, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -45,30 +45,35 @@ from nuitka.Constants import (
 from nuitka.Options import isDebug
 
 from .ExpressionBases import CompileTimeConstantExpressionBase
+from .IterationHandles import (
+    ConstantIndexableIterationHandle,
+    ConstantSetAndDictIterationHandle,
+)
 from .NodeMakingHelpers import (
     getComputationResult,
     makeRaiseExceptionReplacementExpression,
     wrapExpressionWithSideEffects,
 )
 from .shapes.BuiltinTypeShapes import (
-    ShapeTypeBool,
-    ShapeTypeBytearray,
-    ShapeTypeBytes,
-    ShapeTypeDict,
-    ShapeTypeEllipsisType,
-    ShapeTypeFloat,
-    ShapeTypeFrozenset,
-    ShapeTypeInt,
-    ShapeTypeList,
-    ShapeTypeLong,
-    ShapeTypeNoneType,
-    ShapeTypeSet,
-    ShapeTypeSlice,
-    ShapeTypeStr,
-    ShapeTypeTuple,
-    ShapeTypeType,
-    ShapeTypeUnicode,
-    ShapeTypeXrange,
+    tshape_bool,
+    tshape_bytearray,
+    tshape_bytes,
+    tshape_complex,
+    tshape_dict,
+    tshape_ellipsis,
+    tshape_float,
+    tshape_frozenset,
+    tshape_int,
+    tshape_list,
+    tshape_long,
+    tshape_none,
+    tshape_set,
+    tshape_slice,
+    tshape_str,
+    tshape_tuple,
+    tshape_type,
+    tshape_unicode,
+    tshape_xrange,
 )
 
 
@@ -127,9 +132,6 @@ class ExpressionConstantRefBase(CompileTimeConstantExpressionBase):
 
         return result
 
-    def getDetail(self):
-        return repr(self.constant)
-
     @staticmethod
     def isExpressionConstantRef():
         return True
@@ -166,6 +168,12 @@ class ExpressionConstantRefBase(CompileTimeConstantExpressionBase):
 
     getConstant = getCompileTimeConstant
 
+    def getIterationHandle(self):
+        if self.isIterableConstant():
+            return ConstantIndexableIterationHandle(self)
+        else:
+            return None
+
     def isMutable(self):
         return isMutable(self.constant)
 
@@ -372,7 +380,7 @@ class ExpressionConstantNoneRef(ExpressionConstantRefBase):
         return {}
 
     def getTypeShape(self):
-        return ShapeTypeNoneType
+        return tshape_none
 
 
 class ExpressionConstantBoolRefBase(ExpressionConstantRefBase):
@@ -388,7 +396,7 @@ class ExpressionConstantBoolRefBase(ExpressionConstantRefBase):
         return {}
 
     def getTypeShape(self):
-        return ShapeTypeBool
+        return tshape_bool
 
 
 class ExpressionConstantTrueRef(ExpressionConstantBoolRefBase):
@@ -427,7 +435,7 @@ class ExpressionConstantEllipsisRef(ExpressionConstantRefBase):
         return {}
 
     def getTypeShape(self):
-        return ShapeTypeEllipsisType
+        return tshape_ellipsis
 
 
 class ExpressionConstantDictRef(ExpressionConstantRefBase):
@@ -443,11 +451,14 @@ class ExpressionConstantDictRef(ExpressionConstantRefBase):
         return True
 
     def getTypeShape(self):
-        return ShapeTypeDict
+        return tshape_dict
 
     def hasShapeDictionaryExact(self):
         return True
 
+    def getIterationHandle(self):
+        return ConstantSetAndDictIterationHandle(self)
+
 
 class ExpressionConstantTupleRef(ExpressionConstantRefBase):
     kind = "EXPRESSION_CONSTANT_TUPLE_REF"
@@ -464,7 +475,7 @@ class ExpressionConstantTupleRef(ExpressionConstantRefBase):
         return True
 
     def getTypeShape(self):
-        return ShapeTypeTuple
+        return tshape_tuple
 
 
 the_empty_tuple = ()
@@ -502,7 +513,7 @@ class ExpressionConstantListRef(ExpressionConstantRefBase):
         return True
 
     def getTypeShape(self):
-        return ShapeTypeList
+        return tshape_list
 
 
 the_empty_list = []
@@ -540,7 +551,10 @@ class ExpressionConstantSetRef(ExpressionConstantRefBase):
         return True
 
     def getTypeShape(self):
-        return ShapeTypeSet
+        return tshape_set
+
+    def getIterationHandle(self):
+        return ConstantSetAndDictIterationHandle(self)
 
 
 the_empty_set = set()
@@ -578,7 +592,7 @@ class ExpressionConstantFrozensetRef(ExpressionConstantRefBase):
         return True
 
     def getTypeShape(self):
-        return ShapeTypeFrozenset
+        return tshape_frozenset
 
 
 the_empty_frozenset = frozenset()
@@ -616,7 +630,7 @@ class ExpressionConstantIntRef(ExpressionConstantRefBase):
         return True
 
     def getTypeShape(self):
-        return ShapeTypeInt
+        return tshape_int
 
 
 class ExpressionConstantLongRef(ExpressionConstantRefBase):
@@ -634,7 +648,7 @@ class ExpressionConstantLongRef(ExpressionConstantRefBase):
         return True
 
     def getTypeShape(self):
-        return ShapeTypeLong
+        return tshape_long
 
 
 class ExpressionConstantStrRef(ExpressionConstantRefBase):
@@ -652,7 +666,7 @@ class ExpressionConstantStrRef(ExpressionConstantRefBase):
         return True
 
     def getTypeShape(self):
-        return ShapeTypeStr
+        return tshape_str
 
 
 class ExpressionConstantUnicodeRef(ExpressionConstantRefBase):
@@ -670,7 +684,7 @@ class ExpressionConstantUnicodeRef(ExpressionConstantRefBase):
         return True
 
     def getTypeShape(self):
-        return ShapeTypeUnicode
+        return tshape_unicode
 
 
 class ExpressionConstantBytesRef(ExpressionConstantRefBase):
@@ -686,7 +700,7 @@ class ExpressionConstantBytesRef(ExpressionConstantRefBase):
         return True
 
     def getTypeShape(self):
-        return ShapeTypeBytes
+        return tshape_bytes
 
 
 class ExpressionConstantBytearrayRef(ExpressionConstantRefBase):
@@ -702,7 +716,7 @@ class ExpressionConstantBytearrayRef(ExpressionConstantRefBase):
         return True
 
     def getTypeShape(self):
-        return ShapeTypeBytearray
+        return tshape_bytearray
 
 
 class ExpressionConstantFloatRef(ExpressionConstantRefBase):
@@ -720,7 +734,7 @@ class ExpressionConstantFloatRef(ExpressionConstantRefBase):
         return True
 
     def getTypeShape(self):
-        return ShapeTypeFloat
+        return tshape_float
 
 
 class ExpressionConstantComplexRef(ExpressionConstantRefBase):
@@ -737,6 +751,9 @@ class ExpressionConstantComplexRef(ExpressionConstantRefBase):
     def isExpressionConstantComplexRef():
         return True
 
+    def getTypeShape(self):
+        return tshape_complex
+
 
 class ExpressionConstantSliceRef(ExpressionConstantRefBase):
     kind = "EXPRESSION_CONSTANT_SLICE_REF"
@@ -753,7 +770,7 @@ class ExpressionConstantSliceRef(ExpressionConstantRefBase):
         return True
 
     def getTypeShape(self):
-        return ShapeTypeSlice
+        return tshape_slice
 
 
 class ExpressionConstantXrangeRef(ExpressionConstantRefBase):
@@ -771,7 +788,7 @@ class ExpressionConstantXrangeRef(ExpressionConstantRefBase):
         return True
 
     def getTypeShape(self):
-        return ShapeTypeXrange
+        return tshape_xrange
 
 
 class ExpressionConstantTypeRef(ExpressionConstantRefBase):
@@ -789,7 +806,7 @@ class ExpressionConstantTypeRef(ExpressionConstantRefBase):
         return True
 
     def getTypeShape(self):
-        return ShapeTypeType
+        return tshape_type
 
     def computeExpressionCall(self, call_node, call_args, call_kw, trace_collection):
         from nuitka.optimizations.OptimizeBuiltinCalls import computeBuiltinCall
