@@ -1,4 +1,4 @@
-#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2020, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -24,26 +24,27 @@ whose implementation lives here. The creation itself also lives here.
 
 from nuitka.PythonVersions import python_version
 
-from .ExpressionBases import ExpressionChildrenHavingBase
+from .ExpressionBases import ExpressionChildHavingBase
 from .FunctionNodes import ExpressionFunctionEntryPointBase
 from .IndicatorMixins import MarkUnoptimizedFunctionIndicatorMixin
 from .ReturnNodes import StatementReturn, StatementReturnNone
 
 
-class ExpressionMakeGeneratorObject(ExpressionChildrenHavingBase):
+class ExpressionMakeGeneratorObject(ExpressionChildHavingBase):
     kind = "EXPRESSION_MAKE_GENERATOR_OBJECT"
 
-    named_children = ("generator_ref",)
+    named_child = "generator_ref"
+    getGeneratorRef = ExpressionChildHavingBase.childGetter("generator_ref")
 
-    getGeneratorRef = ExpressionChildrenHavingBase.childGetter("generator_ref")
+    __slots__ = ("variable_closure_traces",)
 
     def __init__(self, generator_ref, source_ref):
         assert (
             generator_ref.getFunctionBody().isExpressionGeneratorObjectBody()
         ), generator_ref
 
-        ExpressionChildrenHavingBase.__init__(
-            self, values={"generator_ref": generator_ref}, source_ref=source_ref
+        ExpressionChildHavingBase.__init__(
+            self, value=generator_ref, source_ref=source_ref
         )
 
         self.variable_closure_traces = None
@@ -83,7 +84,7 @@ class ExpressionGeneratorObjectBody(
     if python_version >= 340:
         qualname_setup = None
 
-    def __init__(self, provider, name, code_object, flags, source_ref):
+    def __init__(self, provider, name, code_object, flags, auto_release, source_ref):
         ExpressionFunctionEntryPointBase.__init__(
             self,
             provider=provider,
@@ -91,6 +92,7 @@ class ExpressionGeneratorObjectBody(
             code_object=code_object,
             code_prefix="genexpr" if name == "<genexpr>" else "genobj",
             flags=flags,
+            auto_release=auto_release,
             source_ref=source_ref,
         )
 
@@ -124,8 +126,7 @@ class StatementGeneratorReturn(StatementReturn):
         StatementReturn.__init__(self, expression=expression, source_ref=source_ref)
 
     def computeStatement(self, trace_collection):
-        trace_collection.onExpression(self.getExpression())
-        expression = self.getExpression()
+        expression = trace_collection.onExpression(self.getExpression())
 
         if expression.mayRaiseException(BaseException):
             trace_collection.onExceptionRaiseExit(BaseException)
