@@ -1,4 +1,4 @@
-#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2020, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -76,11 +76,13 @@ class ExpressionOutlineBody(ExpressionChildHavingBase):
 
         return self.temp_scope
 
-    def allocateTempVariable(self, temp_scope, name):
+    def allocateTempVariable(self, temp_scope, name, temp_type=None):
         if temp_scope is None:
             temp_scope = self.getOutlineTempScope()
 
-        return self.provider.allocateTempVariable(temp_scope=temp_scope, name=name)
+        return self.provider.allocateTempVariable(
+            temp_scope=temp_scope, name=name, temp_type=temp_type
+        )
 
     def allocateTempScope(self, name):
 
@@ -274,11 +276,13 @@ class ExpressionOutlineFunctionBodyBase(ExpressionFunctionBodyBase):
 
         return self.temp_scope
 
-    def allocateTempVariable(self, temp_scope, name):
+    def allocateTempVariable(self, temp_scope, name, temp_type=None):
         if temp_scope is None:
             temp_scope = self.getOutlineTempScope()
 
-        return self.provider.allocateTempVariable(temp_scope=temp_scope, name=name)
+        return self.provider.allocateTempVariable(
+            temp_scope=temp_scope, name=name, temp_type=None
+        )
 
     def allocateTempScope(self, name):
 
