@@ -1,4 +1,4 @@
-#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2020, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -87,6 +87,10 @@ class ControlFlowDescriptionComparisonUnorderable(ControlFlowDescriptionFullEsca
     pass
 
 
+class ControlFlowDescriptionFormatError(ControlFlowDescriptionFullEscape):
+    pass
+
+
 class ControlFlowDescriptionOperationUnsupportedBase(ControlFlowDescriptionFullEscape):
     @staticmethod
     def getExceptionExit():
@@ -139,6 +143,12 @@ class ControlFlowDescriptionModUnsupported(
     pass
 
 
+class ControlFlowDescriptionDivmodUnsupported(
+    ControlFlowDescriptionOperationUnsupportedBase
+):
+    pass
+
+
 class ControlFlowDescriptionPowUnsupported(
     ControlFlowDescriptionOperationUnsupportedBase
 ):
@@ -173,3 +183,9 @@ class ControlFlowDescriptionRshiftUnsupported(
     ControlFlowDescriptionOperationUnsupportedBase
 ):
     pass
+
+
+class ControlFlowDescriptionMatmultUnsupported(
+    ControlFlowDescriptionOperationUnsupportedBase
+):
+    pass
