@@ -1,4 +1,4 @@
-#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2020, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -24,7 +24,6 @@ own dependencies.
 import os
 import shutil
 import sys
-from logging import info
 
 from nuitka import Options
 from nuitka.plugins.PluginBase import NuitkaPluginBase
@@ -41,7 +40,7 @@ from nuitka.utils.Utils import isWin32Windows
 
 
 class NuitkaPluginPyQtPySidePlugins(NuitkaPluginBase):
-    """ This is for plugins of PySide/PyQt4/PyQt5.
+    """ This is for plugins of PyQt4/PyQt5 and PySide once it is supported.
 
         When loads an image, it may use a plug-in, which in turn used DLLs,
         which for standalone mode, can cause issues of not having it.
@@ -50,10 +49,26 @@ class NuitkaPluginPyQtPySidePlugins(NuitkaPluginBase):
     plugin_name = "qt-plugins"
     plugin_desc = "Required by the PyQt and PySide packages"
 
-    def __init__(self):
+    def __init__(self, qt_plugins):
+        self.qt_plugins = qt_plugins
+
         self.qt_dirs = {}
         self.webengine_done = False
 
+    @classmethod
+    def addPluginCommandLineOptions(cls, group):
+        group.add_option(
+            "--include-qt-plugins",
+            action="store",
+            dest="qt_plugins",
+            default="sensible",
+            help="""\
+Which Qt plugins to include. These can be big with dependencies, so
+by default only the sensible ones are included, but you can also put
+"all" or list them individually. If you specify something that does
+not exist, a list of all available will be given.""",
+        )
+
     @staticmethod
     def createPreModuleLoadCode(module):
         """ Method called when a module is being imported.
@@ -165,13 +180,9 @@ if os.path.exists(guess_path):
             if not plugin_dirs:
                 sys.exit("Error, failed to detect %s plugin directories." % full_name)
 
-            plugin_options = self.getPluginOptions()
-            plugin_options = set(plugin_options)
             target_plugin_dir = os.path.join(dist_dir, full_name, "qt-plugins")
 
-            # Default to using sensible plugins.
-            if not plugin_options:
-                plugin_options.add("sensible")
+            plugin_options = set(self.qt_plugins.split(","))
 
             if "sensible" in plugin_options:
                 # Most used ones with low dependencies.
@@ -195,7 +206,7 @@ if os.path.exists(guess_path):
                 # indicating the check to be bad.
                 assert plugin_options
 
-            info(
+            self.info(
                 "Copying Qt plug-ins '%s' to '%s'."
                 % (
                     ",".join(sorted(x for x in plugin_options if x != "xml")),
@@ -251,7 +262,7 @@ if os.path.exists(guess_path):
                     [],
                 )
 
-                info("Copying OpenSSL DLLs to %r" % (dist_dir,))
+                self.info("Copying OpenSSL DLLs to %r" % (dist_dir,))
 
                 for filename in qt_bin_files:
                     basename = os.path.basename(filename).lower()
@@ -273,7 +284,7 @@ if os.path.exists(guess_path):
                     os.path.join(target_plugin_dir, "..", "Qt", "qml")
                 )
 
-                info("Copying Qt plug-ins 'xml' to '%s'." % (qml_target_dir))
+                self.info("Copying Qt plug-ins 'xml' to '%s'." % (qml_target_dir))
 
                 copyTree(qml_plugin_dir, qml_target_dir)
 
@@ -307,7 +318,7 @@ if os.path.exists(guess_path):
                 if isWin32Windows():
                     opengl_dlls = ("libegl.dll", "libglesv2.dll", "opengl32sw.dll")
 
-                    info("Copying OpenGL DLLs to %r" % (dist_dir,))
+                    self.info("Copying OpenGL DLLs to %r" % (dist_dir,))
 
                     for filename in qt_bin_files:
                         basename = os.path.basename(filename).lower()
@@ -338,7 +349,8 @@ if os.path.exists(guess_path):
             and not self.webengine_done
         ):
             self.webengine_done = True  # prevent multiple copies
-            info("Copying QtWebEngine components")
+            self.info("Copying QtWebEngine components")
+
             plugin_parent = os.path.dirname(plugin_dirs[0])
 
             if isWin32Windows():
@@ -438,10 +450,10 @@ system Qt plug-ins, which may be from another Qt version.""",
 
 
 class NuitkaPluginDetectorPyQtPySidePlugins(NuitkaPluginBase):
-    plugin_name = "qt-plugins"
+    detector_for = NuitkaPluginPyQtPySidePlugins
 
-    @staticmethod
-    def isRelevant():
+    @classmethod
+    def isRelevant(cls):
         return Options.isStandaloneMode()
 
     def onModuleDiscovered(self, module):
