@@ -1,4 +1,4 @@
-#     Copyright 2019, Jorj McKie, mailto:<jorj.x.mckie@outlook.de>
+#     Copyright 2020, Jorj McKie, mailto:<jorj.x.mckie@outlook.de>
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -17,30 +17,12 @@
 #
 """ Details see below in class definition.
 """
-import os
-import pkgutil
 import sys
-from logging import info
 
 from nuitka import Options
 from nuitka.plugins.PluginBase import NuitkaPluginBase
 
 
-def get_module_file_attribute(package):
-    """ Get the absolute path of the module with the passed-in name.
-
-    Args:
-        package: the fully-qualified name of this module.
-    Returns:
-        absolute path of this module.
-    """
-    loader = pkgutil.find_loader(package)
-    attr = loader.get_filename(package)
-    if not attr:
-        raise ImportError
-    return os.path.dirname(attr)
-
-
 class TensorflowPlugin(NuitkaPluginBase):
     """ This class represents the main logic of the plugin.
 
@@ -62,17 +44,11 @@ class TensorflowPlugin(NuitkaPluginBase):
         self.files_copied = False
         return None
 
-    def onModuleEncounter(
-        self, module_filename, module_name, module_package, module_kind
-    ):
-        if module_package is not None:
-            full_name = module_package + "." + module_name
-        else:
-            full_name = module_name
+    def onModuleEncounter(self, module_filename, module_name, module_kind):
 
         for candidate in ("tensor", "google"):
-            if full_name == candidate or full_name.startswith(candidate + "."):
-                return True, "accept everything from %s" % candidate
+            if module_name.hasNamespace(candidate):
+                return True, "Accept everything from %s" % candidate
 
     def onModuleSourceCode(self, module_name, source_code):
         """ Neutralize some path magic in tensorflow.
@@ -93,10 +69,9 @@ class TensorflowPlugin(NuitkaPluginBase):
                 break
 
         if found_insert is True:
-            info(
-                "'%s' plugin: Patched 'running-from-pip' path magic." % self.plugin_name
-            )
+            self.info("Patched 'running-from-pip' path magic.")
         else:
+            # TODO: Add method for exit to logger too.
             sys.exit("'%s' plugin did not find path magic." % self.plugin_name)
 
         return "\n".join(source_lines)
@@ -109,8 +84,8 @@ class TensorflowPlugin(NuitkaPluginBase):
             create the actual application. Therefore, compilation makes no
             sense for it and the packages it references.
         """
-
-        for candidate in (
+        elements = module_name.split(".")
+        if elements[0] in (
             "tensor",
             "boto",
             "google",
@@ -119,8 +94,9 @@ class TensorflowPlugin(NuitkaPluginBase):
             "pandas",
             "matplotlib",
         ):
-            if module_name == candidate or module_name.startswith(candidate + "."):
-                return "bytecode"
+            return "bytecode"
+        else:
+            return "compiled"
 
 
 class TensorflowPluginDetector(NuitkaPluginBase):
@@ -130,10 +106,10 @@ class TensorflowPluginDetector(NuitkaPluginBase):
         We are given the chance to issue a warning if we think we may be required.
     """
 
-    plugin_name = "tensorflow"  # Nuitka knows us by this name
+    detector_for = TensorflowPlugin
 
-    @staticmethod
-    def isRelevant():
+    @classmethod
+    def isRelevant(cls):
         """ This method is called one time only to check, whether the plugin might make sense at all.
 
         Returns:
