@@ -1,4 +1,4 @@
-#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2020, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -33,7 +33,14 @@ class BuiltinParameterSpec(ParameterSpec):
     __slots__ = ("builtin",)
 
     def __init__(
-        self, name, arg_names, default_count, list_star_arg=None, dict_star_arg=None
+        self,
+        name,
+        arg_names,
+        default_count,
+        list_star_arg=None,
+        dict_star_arg=None,
+        pos_only_args=(),
+        kw_only_args=(),
     ):
         ParameterSpec.__init__(
             self,
@@ -42,12 +49,13 @@ class BuiltinParameterSpec(ParameterSpec):
             ps_list_star_arg=list_star_arg,
             ps_dict_star_arg=dict_star_arg,
             ps_default_count=default_count,
-            ps_kw_only_args=(),
+            ps_pos_only_args=pos_only_args,
+            ps_kw_only_args=kw_only_args,
         )
 
         self.builtin = getattr(builtins, name)
 
-        assert default_count <= len(arg_names)
+        assert default_count <= len(arg_names) + len(kw_only_args) + len(pos_only_args)
 
     def __repr__(self):
         return "<BuiltinParameterSpec %s>" % self.name
@@ -71,10 +79,10 @@ class BuiltinParameterSpec(ParameterSpec):
         # fatal, pylint: disable=broad-except,too-many-branches
 
         try:
-            given_normal_args = given_values[: len(self.normal_args)]
+            given_normal_args = given_values[: self.getArgumentCount()]
 
             if self.list_star_arg:
-                given_list_star_args = given_values[len(self.normal_args)]
+                given_list_star_args = given_values[self.getArgumentCount()]
             else:
                 given_list_star_args = None
 
@@ -85,7 +93,9 @@ class BuiltinParameterSpec(ParameterSpec):
 
             arg_dict = {}
 
-            for arg_name, given_value in zip(self.normal_args, given_normal_args):
+            for arg_name, given_value in zip(
+                self.getArgumentNames(), given_normal_args
+            ):
                 assert type(given_value) not in (
                     tuple,
                     list,
@@ -103,10 +113,12 @@ class BuiltinParameterSpec(ParameterSpec):
 
             arg_list = []
 
-            for arg_name in self.normal_args[: self.getPositionalOnlyCount()]:
-                if arg_name in arg_dict:
-                    arg_list.append(arg_dict[arg_name])
-                    del arg_dict[arg_name]
+            for arg_name in self.getArgumentNames():
+                if arg_name not in arg_dict:
+                    break
+
+                arg_list.append(arg_dict[arg_name])
+                del arg_dict[arg_name]
 
         except Exception as e:
             sys.exit("Fatal problem: %r" % e)
@@ -137,14 +149,14 @@ class BuiltinParameterSpecNoKeywords(BuiltinParameterSpec):
 
         try:
             if self.list_star_arg:
-                given_list_star_arg = given_values[len(self.normal_args)]
+                given_list_star_arg = given_values[self.getArgumentCount()]
             else:
                 given_list_star_arg = None
 
             arg_list = []
             refuse_more = False
 
-            for _arg_name, given_value in zip(self.normal_args, given_values):
+            for _arg_name, given_value in zip(self.getArgumentNames(), given_values):
                 assert type(given_value) not in (
                     tuple,
                     list,
@@ -172,9 +184,20 @@ class BuiltinParameterSpecNoKeywords(BuiltinParameterSpec):
         return self.builtin(*arg_list)
 
 
+class BuiltinParameterSpecExceptionsKwOnly(BuiltinParameterSpec):
+    def __init__(self, exception_name, kw_only_args):
+        BuiltinParameterSpec.__init__(
+            self,
+            name=exception_name,
+            arg_names=(),
+            default_count=len(kw_only_args),  # For exceptions, they will be required.
+            list_star_arg="args",
+            kw_only_args=kw_only_args,
+        )
+
+
 class BuiltinParameterSpecExceptions(BuiltinParameterSpec):
     def __init__(self, exception_name):
-        # TODO: Parameter default_count makes no sense for exceptions probably.
         BuiltinParameterSpec.__init__(
             self,
             name=exception_name,
@@ -193,15 +216,33 @@ class BuiltinParameterSpecExceptions(BuiltinParameterSpec):
         return "exceptions." + self.getName()
 
 
-class BuiltinParameterSpecPosArgs(BuiltinParameterSpec):
-    __slots__ = ("positional_only",)
+def makeBuiltinExceptionParameterSpec(exception_name):
+    """ Factory function to create parameter spec for an exception from its name.
 
+    Args:
+        exception_name - (str) name of the built-in exception
+
+    Returns:
+        ParameterSpec that can be used to evaluate calls of these exceptions.
+    """
+    if exception_name == "ImportError" and python_version >= 300:
+        # This is currently the only known built-in exception that does it, but let's
+        # be general, as surely that list is going to expand only.
+
+        return BuiltinParameterSpecExceptionsKwOnly(
+            exception_name=exception_name, kw_only_args=("name", "path")
+        )
+    else:
+        return BuiltinParameterSpecExceptions(exception_name=exception_name)
+
+
+class BuiltinParameterSpecPosArgs(BuiltinParameterSpec):
     def __init__(
         self,
         name,
+        pos_only_args,
         arg_names,
         default_count,
-        positional_only,
         list_star_arg=None,
         dict_star_arg=None,
     ):
@@ -210,87 +251,93 @@ class BuiltinParameterSpecPosArgs(BuiltinParameterSpec):
             name=name,
             arg_names=arg_names,
             default_count=default_count,
+            pos_only_args=pos_only_args,
             list_star_arg=list_star_arg,
             dict_star_arg=dict_star_arg,
         )
 
-        # Kind of the point of this class.
-        assert positional_only
-        self.positional_only = positional_only
-
-    def getPositionalOnlyCount(self):
-        return self.positional_only
-
-
-def makeBuiltinExceptionParameterSpec(exception_name):
-    if exception_name == "ImportError" and python_version >= 300:
-        # TODO: Create this beast, needs keyword only arguments to be supported,
-        # currently user of this function must take care to not have them.
-        pass
-
-    return BuiltinParameterSpecExceptions(exception_name=exception_name)
-
 
 if python_version < 370:
-    builtin_int_spec = BuiltinParameterSpec("int", ("x", "base"), 2)
+    builtin_int_spec = BuiltinParameterSpec("int", ("x", "base"), default_count=2)
 else:
-    builtin_int_spec = BuiltinParameterSpecPosArgs("int", ("x", "base"), 2, 1)
+    builtin_int_spec = BuiltinParameterSpecPosArgs(
+        "int", ("x",), ("base",), default_count=2
+    )
 
 
 # These builtins are only available for Python2
 if python_version < 300:
-    builtin_long_spec = BuiltinParameterSpec("long", ("x", "base"), 2)
+    builtin_long_spec = BuiltinParameterSpec("long", ("x", "base"), default_count=2)
     builtin_execfile_spec = BuiltinParameterSpecNoKeywords(
-        "execfile", ("filename", "globals", "locals"), 2
+        "execfile", ("filename", "globals", "locals"), default_count=2
     )
     builtin_unicode_spec = BuiltinParameterSpec(
-        "unicode", ("string", "encoding", "errors"), 3
+        "unicode", ("string", "encoding", "errors"), default_count=3
     )
 
 builtin_xrange_spec = BuiltinParameterSpecNoKeywords(
-    "xrange" if python_version < 300 else "range", ("start", "stop", "step"), 2
+    "xrange" if python_version < 300 else "range",
+    ("start", "stop", "step"),
+    default_count=2,
 )
 
 
 if python_version < 370:
-    builtin_bool_spec = BuiltinParameterSpec("bool", ("x",), 1)
+    builtin_bool_spec = BuiltinParameterSpec("bool", ("x",), default_count=1)
 else:
-    builtin_bool_spec = BuiltinParameterSpecNoKeywords("bool", ("x",), 1)
+    builtin_bool_spec = BuiltinParameterSpecNoKeywords("bool", ("x",), default_count=1)
 
 if python_version < 370:
-    builtin_float_spec = BuiltinParameterSpec("float", ("x",), 1)
+    builtin_float_spec = BuiltinParameterSpec("float", ("x",), default_count=1)
 else:
-    builtin_float_spec = BuiltinParameterSpecNoKeywords("float", ("x",), 1)
+    builtin_float_spec = BuiltinParameterSpecNoKeywords(
+        "float", ("x",), default_count=1
+    )
 
-builtin_complex_spec = BuiltinParameterSpec("complex", ("real", "imag"), 2)
+builtin_complex_spec = BuiltinParameterSpec(
+    "complex", ("real", "imag"), default_count=2
+)
 
 # This built-in have variable parameters for Python2/3
 if python_version < 300:
-    builtin_str_spec = BuiltinParameterSpec("str", ("object",), 1)
+    builtin_str_spec = BuiltinParameterSpec("str", ("object",), default_count=1)
 else:
-    builtin_str_spec = BuiltinParameterSpec("str", ("object", "encoding", "errors"), 3)
+    builtin_str_spec = BuiltinParameterSpec(
+        "str", ("object", "encoding", "errors"), default_count=3
+    )
 
-builtin_len_spec = BuiltinParameterSpecNoKeywords("len", ("object",), 0)
-builtin_dict_spec = BuiltinParameterSpec("dict", (), 0, "list_args", "dict_args")
-builtin_len_spec = BuiltinParameterSpecNoKeywords("len", ("object",), 0)
-builtin_any_spec = BuiltinParameterSpecNoKeywords("any", ("object",), 0)
+builtin_len_spec = BuiltinParameterSpecNoKeywords("len", ("object",), default_count=0)
+builtin_dict_spec = BuiltinParameterSpec(
+    "dict", (), default_count=0, list_star_arg="list_args", dict_star_arg="dict_args"
+)
+builtin_any_spec = BuiltinParameterSpecNoKeywords("any", ("object",), default_count=0)
+builtin_abs_spec = BuiltinParameterSpecNoKeywords("abs", ("object",), default_count=0)
+builtin_all_spec = BuiltinParameterSpecNoKeywords("all", ("object",), default_count=0)
 
 if python_version < 370:
-    builtin_tuple_spec = BuiltinParameterSpec("tuple", ("sequence",), 1)
-    builtin_list_spec = BuiltinParameterSpec("list", ("sequence",), 1)
+    builtin_tuple_spec = BuiltinParameterSpec("tuple", ("sequence",), default_count=1)
+    builtin_list_spec = BuiltinParameterSpec("list", ("sequence",), default_count=1)
 else:
-    builtin_tuple_spec = BuiltinParameterSpecNoKeywords("tuple", ("sequence",), 1)
-    builtin_list_spec = BuiltinParameterSpecNoKeywords("list", ("sequence",), 1)
+    builtin_tuple_spec = BuiltinParameterSpecNoKeywords(
+        "tuple", ("sequence",), default_count=1
+    )
+    builtin_list_spec = BuiltinParameterSpecNoKeywords(
+        "list", ("sequence",), default_count=1
+    )
 
-builtin_set_spec = BuiltinParameterSpecNoKeywords("set", ("iterable",), 1)
-builtin_frozenset_spec = BuiltinParameterSpecNoKeywords("frozenset", ("iterable",), 1)
+builtin_set_spec = BuiltinParameterSpecNoKeywords("set", ("iterable",), default_count=1)
+builtin_frozenset_spec = BuiltinParameterSpecNoKeywords(
+    "frozenset", ("iterable",), default_count=1
+)
 
 builtin_import_spec = BuiltinParameterSpec(
-    "__import__", ("name", "globals", "locals", "fromlist", "level"), 4
+    "__import__", ("name", "globals", "locals", "fromlist", "level"), default_count=4
 )
 
 if python_version < 300:
-    builtin_open_spec = BuiltinParameterSpec("open", ("name", "mode", "buffering"), 3)
+    builtin_open_spec = BuiltinParameterSpec(
+        "open", ("name", "mode", "buffering"), default_count=3
+    )
 else:
     builtin_open_spec = BuiltinParameterSpec(
         "open",
@@ -304,65 +351,75 @@ else:
             "closefd",
             "opener",
         ),
-        7,
+        default_count=7,
     )
 
-builtin_chr_spec = BuiltinParameterSpecNoKeywords("chr", ("i",), 0)
-builtin_ord_spec = BuiltinParameterSpecNoKeywords("ord", ("c",), 0)
-builtin_bin_spec = BuiltinParameterSpecNoKeywords("bin", ("number",), 0)
-builtin_oct_spec = BuiltinParameterSpecNoKeywords("oct", ("number",), 0)
-builtin_hex_spec = BuiltinParameterSpecNoKeywords("hex", ("number",), 0)
-builtin_id_spec = BuiltinParameterSpecNoKeywords("id", ("object",), 0)
-builtin_repr_spec = BuiltinParameterSpecNoKeywords("repr", ("object",), 0)
+builtin_chr_spec = BuiltinParameterSpecNoKeywords("chr", ("i",), default_count=0)
+builtin_ord_spec = BuiltinParameterSpecNoKeywords("ord", ("c",), default_count=0)
+builtin_bin_spec = BuiltinParameterSpecNoKeywords("bin", ("number",), default_count=0)
+builtin_oct_spec = BuiltinParameterSpecNoKeywords("oct", ("number",), default_count=0)
+builtin_hex_spec = BuiltinParameterSpecNoKeywords("hex", ("number",), default_count=0)
+builtin_id_spec = BuiltinParameterSpecNoKeywords("id", ("object",), default_count=0)
+builtin_repr_spec = BuiltinParameterSpecNoKeywords("repr", ("object",), default_count=0)
 
-builtin_dir_spec = BuiltinParameterSpecNoKeywords("dir", ("object",), 1)
-builtin_vars_spec = BuiltinParameterSpecNoKeywords("vars", ("object",), 1)
+builtin_dir_spec = BuiltinParameterSpecNoKeywords("dir", ("object",), default_count=1)
+builtin_vars_spec = BuiltinParameterSpecNoKeywords("vars", ("object",), default_count=1)
 
-builtin_locals_spec = BuiltinParameterSpecNoKeywords("locals", (), 0)
-builtin_globals_spec = BuiltinParameterSpecNoKeywords("globals", (), 0)
+builtin_locals_spec = BuiltinParameterSpecNoKeywords("locals", (), default_count=0)
+builtin_globals_spec = BuiltinParameterSpecNoKeywords("globals", (), default_count=0)
 builtin_eval_spec = BuiltinParameterSpecNoKeywords(
     "eval", ("source", "globals", "locals"), 2
 )
 if python_version < 300:
     builtin_compile_spec = BuiltinParameterSpec(
-        "compile", ("source", "filename", "mode", "flags", "dont_inherit"), 2
+        "compile",
+        ("source", "filename", "mode", "flags", "dont_inherit"),
+        default_count=2,
     )
 else:
     builtin_compile_spec = BuiltinParameterSpec(
         "compile",
         ("source", "filename", "mode", "flags", "dont_inherit", "optimize"),
-        3,
+        default_count=3,
     )
 if python_version >= 300:
     builtin_exec_spec = BuiltinParameterSpecNoKeywords(
-        "exec", ("source", "globals", "locals"), 2
+        "exec", ("source", "globals", "locals"), default_count=2
     )
 
 # Note: Iter in fact names its first argument if the default applies
 # "collection", fixed up in a wrapper.
-builtin_iter_spec = BuiltinParameterSpecNoKeywords("iter", ("callable", "sentinel"), 1)
-builtin_next_spec = BuiltinParameterSpecNoKeywords("next", ("iterator", "default"), 1)
+builtin_iter_spec = BuiltinParameterSpecNoKeywords(
+    "iter", ("callable", "sentinel"), default_count=1
+)
+builtin_next_spec = BuiltinParameterSpecNoKeywords(
+    "next", ("iterator", "default"), default_count=1
+)
 
 # Note: type with 1 and type with 3 arguments are too different.
-builtin_type1_spec = BuiltinParameterSpecNoKeywords("type", ("object",), 0)
+builtin_type1_spec = BuiltinParameterSpecNoKeywords(
+    "type", ("object",), default_count=0
+)
 builtin_type3_spec = BuiltinParameterSpecNoKeywords(
-    "type", ("name", "bases", "dict"), 0
+    "type", ("name", "bases", "dict"), default_count=0
 )
 
 builtin_super_spec = BuiltinParameterSpecNoKeywords(
-    "super", ("type", "object"), 1 if python_version < 300 else 2
+    "super", ("type", "object"), default_count=1 if python_version < 300 else 2
 )
 
-builtin_hasattr_spec = BuiltinParameterSpecNoKeywords("hasattr", ("object", "name"), 0)
+builtin_hasattr_spec = BuiltinParameterSpecNoKeywords(
+    "hasattr", ("object", "name"), default_count=0
+)
 builtin_getattr_spec = BuiltinParameterSpecNoKeywords(
-    "getattr", ("object", "name", "default"), 1
+    "getattr", ("object", "name", "default"), default_count=1
 )
 builtin_setattr_spec = BuiltinParameterSpecNoKeywords(
-    "setattr", ("object", "name", "value"), 0
+    "setattr", ("object", "name", "value"), default_count=0
 )
 
 builtin_isinstance_spec = BuiltinParameterSpecNoKeywords(
-    "isinstance", ("instance", "classes"), 0
+    "isinstance", ("instance", "classes"), default_count=0
 )
 
 
@@ -385,52 +442,67 @@ class BuiltinBytearraySpec(BuiltinParameterSpecPosArgs):
 
 
 builtin_bytearray_spec = BuiltinBytearraySpec(
-    "bytearray", ("string", "encoding", "errors"), 2, 1
+    "bytearray", ("string",), ("encoding", "errors"), default_count=2
 )
 
 if python_version >= 300:
     builtin_bytes_spec = BuiltinBytearraySpec(
-        "bytes", ("string", "encoding", "errors"), 3, 1
+        "bytes", ("string",), ("encoding", "errors"), default_count=3
     )
 
 
 # Beware: One argument version defines "stop", not "start".
 builtin_slice_spec = BuiltinParameterSpecNoKeywords(
-    "slice", ("start", "stop", "step"), 2
+    "slice", ("start", "stop", "step"), default_count=2
 )
 
-builtin_hash_spec = BuiltinParameterSpecNoKeywords("hash", ("object",), 0)
+builtin_hash_spec = BuiltinParameterSpecNoKeywords("hash", ("object",), default_count=0)
 
 builtin_format_spec = BuiltinParameterSpecNoKeywords(
-    "format", ("value", "format_spec"), 1
+    "format", ("value", "format_spec"), default_count=1
 )
 
-builtin_sum_spec = BuiltinParameterSpecNoKeywords("sum", ("sequence", "start"), 1)
+if python_version < 380:
+    builtin_sum_spec = BuiltinParameterSpecNoKeywords(
+        "sum", ("sequence", "start"), default_count=1
+    )
+else:
+    builtin_sum_spec = BuiltinParameterSpecPosArgs(
+        "sum", ("sequence",), ("start",), default_count=1
+    )
 
 builtin_staticmethod_spec = BuiltinParameterSpecNoKeywords(
-    "staticmethod", ("function",), 0
+    "staticmethod", ("function",), default_count=0
 )
 builtin_classmethod_spec = BuiltinParameterSpecNoKeywords(
-    "classmethod", ("function",), 0
+    "classmethod", ("function",), default_count=0
 )
 
 if python_version < 300:
     builtin_sorted_spec = BuiltinParameterSpecNoKeywords(
-        "sorted", ("iterable", "cmp", "key", "reverse"), 2
+        "sorted", ("iterable", "cmp", "key", "reverse"), default_count=2
     )
 else:
     builtin_sorted_spec = BuiltinParameterSpecNoKeywords(
-        "sorted", ("iterable", "key", "reverse"), 2
+        "sorted", ("iterable", "key", "reverse"), default_count=2
     )
 
-builtin_reversed_spec = BuiltinParameterSpecNoKeywords("reversed", ("object",), 0)
+builtin_reversed_spec = BuiltinParameterSpecNoKeywords(
+    "reversed", ("object",), default_count=0
+)
 
-builtin_reversed_spec = BuiltinParameterSpecNoKeywords("reversed", ("object",), 0)
+builtin_reversed_spec = BuiltinParameterSpecNoKeywords(
+    "reversed", ("object",), default_count=0
+)
 
 if python_version < 300:
-    builtin_enumerate_spec = BuiltinParameterSpec("enumerate", ("sequence",), 0)
+    builtin_enumerate_spec = BuiltinParameterSpec(
+        "enumerate", ("sequence",), default_count=0
+    )
 else:
-    builtin_enumerate_spec = BuiltinParameterSpec("enumerate", ("iterable",), 0)
+    builtin_enumerate_spec = BuiltinParameterSpec(
+        "enumerate", ("iterable",), default_count=0
+    )
 
 
 class BuiltinRangeSpec(BuiltinParameterSpecNoKeywords):
@@ -497,13 +569,19 @@ class BuiltinRangeSpec(BuiltinParameterSpecNoKeywords):
             return False
 
 
-builtin_range_spec = BuiltinRangeSpec("range", ("start", "stop", "step"), 2)
+builtin_range_spec = BuiltinRangeSpec(
+    "range", ("start", "stop", "step"), default_count=2
+)
 
 if python_version >= 300:
-    builtin_ascii_spec = BuiltinParameterSpecNoKeywords("ascii", ("object",), 0)
+    builtin_ascii_spec = BuiltinParameterSpecNoKeywords(
+        "ascii", ("object",), default_count=0
+    )
 
 
-builtin_divmod_spec = BuiltinParameterSpecNoKeywords("divmod", ("left", "right"), 0)
+builtin_divmod_spec = BuiltinParameterSpecNoKeywords(
+    "divmod", ("left", "right"), default_count=0
+)
 
 
 def extractBuiltinArgs(node, builtin_spec, builtin_class, empty_special_class=None):
@@ -541,10 +619,11 @@ def extractBuiltinArgs(node, builtin_spec, builtin_class, empty_special_class=No
         args_dict = matchCall(
             func_name=builtin_spec.getName(),
             args=builtin_spec.getArgumentNames(),
+            kw_only_args=builtin_spec.getKwOnlyParameterNames(),
             star_list_arg=builtin_spec.getStarListArgumentName(),
             star_dict_arg=builtin_spec.getStarDictArgumentName(),
             num_defaults=builtin_spec.getDefaultCount(),
-            num_posonly=builtin_spec.getPositionalOnlyCount(),
+            num_posonly=builtin_spec.getPosOnlyParameterCount(),
             positional=positional,
             pairs=pairs,
         )
@@ -562,6 +641,8 @@ def extractBuiltinArgs(node, builtin_spec, builtin_class, empty_special_class=No
             side_effects=node.extractSideEffectsPreCall(),
         )
 
+    # Using list reference for passing the arguments without names where it
+    # it possible, otherwise dictionary to make those distinuishable.
     args_list = []
 
     for argument_name in builtin_spec.getArgumentNames():
@@ -573,6 +654,9 @@ def extractBuiltinArgs(node, builtin_spec, builtin_class, empty_special_class=No
     if builtin_spec.getStarDictArgumentName() is not None:
         args_list.append(args_dict[builtin_spec.getStarDictArgumentName()])
 
+    for argument_name in builtin_spec.getKwOnlyParameterNames():
+        args_list.append(args_dict[argument_name])
+
     # Using list reference for passing the arguments without names,
     result = builtin_class(*args_list, source_ref=node.getSourceReference())
 
