@@ -1,4 +1,4 @@
-#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2020, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -21,6 +21,7 @@ from __future__ import print_function
 
 import ast
 import atexit
+import gc
 import hashlib
 import os
 import re
@@ -208,7 +209,7 @@ def convertUsing2to3(path, force=False):
     else:
         command = [sys.executable, "-m", "lib2to3"]
 
-    command += ["-w", "-n", "--no-diffs", new_path]
+    command += ("-w", "-n", "--no-diffs", new_path)
 
     with open(os.devnull, "w") as devnull:
         try:
@@ -256,6 +257,9 @@ def decideFilenameVersionSkip(filename):
     if filename.startswith("run_"):
         return False
 
+    if filename.endswith(".j2"):
+        filename = filename[:-3]
+
     # Skip tests that require Python 2.7 at least.
     if filename.endswith("27.py") and _python_version.startswith("2.6"):
         return False
@@ -791,80 +795,178 @@ m1 = {}
 m2 = {}
 
 
-def snapObjRefCntMap(before):
-    import gc
+def cleanObjRefCntMaps():
+    m1.clear()
+    m2.clear()
 
+    # Warm out repr
+    for x in gc.get_objects():
+        try:
+            str(x)
+        except Exception:  # Catch all the things, pylint: disable=broad-except
+            pass
+
+
+def snapObjRefCntMap(before):
     if before:
         m = m1
     else:
         m = m2
 
+    m.clear()
+    gc.collect()
+
     for x in gc.get_objects():
-        if x is m1:
+        # The dictionary is cyclic, and contains itself, avoid that.
+        if x is m1 or x is m2:
             continue
 
-        if x is m2:
+        if type(x) is str and (x in m1 or x in m2):
             continue
 
-        m[str(x)] = sys.getrefcount(x)
+        if type(x) is not str and isinstance(x, str):
+            k = "str_overload_" + x.__class__.__name__ + str(x)
+        elif type(x) is dict:
+            if "__builtins__" in x:
+                k = "<module dict %s>" % x["__name__"]
+            elif "__spec__" in x and "__name__" in x:
+                k = "<module dict %s>" % x["__name__"]
+            else:
+                k = str(x)
+        elif x.__class__.__name__ == "compiled_frame":
+            k = "<compiled_frame at xxx, line %d code %s" % (x.f_lineno, x.f_code)
+        else:
+            k = str(x)
+
+        c = sys.getrefcount(x)
+
+        if k in m:
+            m[k] += c
+        else:
+            m[k] = c
 
 
-def checkReferenceCount(checked_function, max_rounds=10):
+orig_print = None
+
+
+def disablePrinting():
+    # Singleton, pylint: disable=global-statement
+    global orig_print
+
+    if orig_print is None:
+        orig_print = __builtins__["print"]
+        __builtins__["print"] = lambda *args, **kwargs: None
+
+
+def reenablePrinting():
+    # Singleton, pylint: disable=global-statement
+    global orig_print
+
+    if orig_print is not None:
+        __builtins__["print"] = orig_print
+        orig_print = None
+
+
+_debug_python = hasattr(sys, "gettotalrefcount")
+
+
+def getTotalReferenceCount():
+    if _debug_python:
+        gc.collect()
+        return sys.gettotalrefcount()
+    else:
+        gc.collect()
+        all_objects = gc.get_objects()
+
+        # Sum object reference twice, once without the sum value type, then switch
+        # the type, and use the type used to avoid the integers before that.
+        result = 0.0
+        for obj in all_objects:
+            if type(obj) is float:
+                continue
+
+            result += sys.getrefcount(obj)
+
+        result = int(result)
+
+        for obj in all_objects:
+            if type(obj) is not float:
+                continue
+
+            result += sys.getrefcount(obj)
+
+        return result
+
+
+def checkReferenceCount(checked_function, max_rounds=20, explain=False):
+    # This is obviously going to be complex, pylint: disable=too-many-branches
+
+    # Clean start conditions.
     assert sys.exc_info() == (None, None, None), sys.exc_info()
 
     print(checked_function.__name__ + ": ", end="")
     sys.stdout.flush()
 
+    disablePrinting()
+
+    # Make sure reference for these are already taken at the start.
     ref_count1 = 17
     ref_count2 = 17
 
-    explain = False
-
-    import gc
+    if explain:
+        cleanObjRefCntMaps()
 
     assert max_rounds > 0
-    for count in range(max_rounds):
-        gc.collect()
-        ref_count1 = sys.gettotalrefcount()
 
+    result = False
+
+    for count in range(max_rounds):
         if explain and count == max_rounds - 1:
-            snapObjRefCntMap(True)
+            snapObjRefCntMap(before=True)
+
+        ref_count1 = getTotalReferenceCount()
 
         checked_function()
 
+        ref_count2 = getTotalReferenceCount()
+
         # Not allowed, but happens when bugs occur.
         assert sys.exc_info() == (None, None, None), sys.exc_info()
 
-        gc.collect()
-
-        if explain and count == max_rounds - 1:
-            snapObjRefCntMap(False)
-
-        ref_count2 = sys.gettotalrefcount()
-
         if ref_count1 == ref_count2:
             result = True
-            print("PASSED")
             break
 
-        # print count, ref_count1, ref_count2
+        if explain and count == max_rounds - 1:
+            snapObjRefCntMap(before=False)
+
+    reenablePrinting()
+
+    if result:
+        print("PASSED")
     else:
-        result = False
         print("FAILED", ref_count1, ref_count2, "leaked", ref_count2 - ref_count1)
 
         if explain:
+            print("REPORT of differences:")
             assert m1
             assert m2
 
             for key in m1:
                 if key not in m2:
                     print("*" * 80)
-                    print("extra", key)
+                    print("extra:", m1[key], key)
                 elif m1[key] != m2[key]:
                     print("*" * 80)
                     print(m1[key], "->", m2[key], key)
                 else:
                     pass
+
+            for key in m2:
+                if key not in m1:
+                    print("*" * 80)
+                    print("missing:", m2[key], key)
+
                     # print m1[key]
 
     assert sys.exc_info() == (None, None, None), sys.exc_info()
@@ -913,9 +1015,7 @@ def reportSkip(reason, dirname, filename):
     my_print("Skipped, %s (%s)." % (case, reason))
 
 
-def executeReferenceChecked(prefix, names, tests_skipped, tests_stderr):
-    import gc
-
+def executeReferenceChecked(prefix, names, tests_skipped, tests_stderr, explain=False):
     gc.disable()
 
     extract_number = lambda name: int(name.replace(prefix, ""))
@@ -943,10 +1043,10 @@ def executeReferenceChecked(prefix, names, tests_skipped, tests_stderr):
             if number in tests_stderr:
                 sys.stderr = open(os.devnull, "wb")
         except OSError:  # Windows
-            if not checkReferenceCount(names[name]):
+            if not checkReferenceCount(names[name], explain=explain):
                 result = False
         else:
-            if not checkReferenceCount(names[name]):
+            if not checkReferenceCount(names[name], explain=explain):
                 result = False
 
             if number in tests_stderr:
@@ -958,17 +1058,6 @@ def executeReferenceChecked(prefix, names, tests_skipped, tests_stderr):
     return result
 
 
-def checkDebugPython():
-    if not hasattr(sys, "gettotalrefcount"):
-        my_print("Warning, using non-debug Python makes this test ineffective.")
-        sys.gettotalrefcount = lambda: 0
-    elif sys.version_info >= (3, 7, 0) and sys.version_info < (3, 7, 1):
-        my_print(
-            "Warning, bug of CPython 3.7.0/1 breaks reference counting and makes this test ineffective."
-        )
-        sys.gettotalrefcount = lambda: 0
-
-
 def addToPythonPath(python_path, in_front=False):
     if type(python_path) in (tuple, list):
         python_path = os.pathsep.join(python_path)
@@ -1131,6 +1220,7 @@ except Exception as __e:
 
         return evaluated.split()[0] in (
             "def",
+            "with",
             "class",
             "for",
             "while",
@@ -1301,6 +1391,52 @@ def withDirectoryChange(path, allow_none=False):
         os.chdir(old_cwd)
 
 
+def scanDirectoryForTestCases(dirname, template_context=None):
+    filenames = os.listdir(dirname)
+
+    filenames = [
+        filename
+        for filename in filenames
+        if (filename.endswith(".py") and not filename + ".j2" in filenames)
+        or filename.endswith(".j2")
+    ]
+
+    # Jinja2 environment is optional.
+    env = None
+
+    for filename in sorted(filenames):
+        if not decideFilenameVersionSkip(filename):
+            continue
+
+        if filename.endswith(".j2"):
+            # Needs to be a dictionary with template arguments.
+            assert template_context is not None
+
+            if env is None:
+                import jinja2
+
+                env = jinja2.Environment(
+                    loader=jinja2.FileSystemLoader("."),
+                    trim_blocks=True,
+                    lstrip_blocks=True,
+                )
+                env.undefined = jinja2.StrictUndefined
+
+            template = env.get_template(filename)
+
+            code = template.render(name=template.name, **template_context)
+
+            filename = filename[:-3]
+            with open(filename, "w") as output:
+                output.write(
+                    "'''Automatically generated test, not part of releases or git.\n\n'''\n"
+                )
+
+                output.write(code)
+
+        yield filename
+
+
 def setupCacheHashSalt(test_code_path):
     assert os.path.exists(test_code_path)
 
