@@ -1,4 +1,4 @@
-#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2020, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -34,7 +34,11 @@ from nuitka.nodes.ReturnNodes import StatementReturn
 from nuitka.nodes.VariableRefNodes import ExpressionTempVariableRef
 
 from .ReformulationTryFinallyStatements import makeTryFinallyStatement
-from .TreeHelpers import buildNode, getKind, makeStatementsSequenceFromStatement
+from .TreeHelpers import (
+    buildNode,
+    getKind,
+    makeStatementsSequenceFromStatement,
+)
 
 
 def _makeComparisonNode(left, right, comparator, source_ref):
