@@ -1,4 +1,4 @@
-#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2020, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -54,24 +54,20 @@ loops.
 
 """
 
-from nuitka.nodes.AssignNodes import (
-    StatementAssignmentVariable,
-    StatementReleaseVariable,
-)
+from nuitka.nodes.AssignNodes import StatementAssignmentVariable
 from nuitka.nodes.ComparisonNodes import ExpressionComparisonIs
 from nuitka.nodes.ConditionalNodes import makeStatementConditional
 from nuitka.nodes.ConstantRefNodes import makeConstantRefNode
 from nuitka.nodes.LoopNodes import StatementLoop, StatementLoopBreak
-from nuitka.nodes.OperatorNodes import ExpressionOperationNOT
+from nuitka.nodes.OperatorNodes import ExpressionOperationNot
 from nuitka.nodes.StatementNodes import StatementsSequence
 from nuitka.nodes.VariableRefNodes import ExpressionTempVariableRef
 
-from .ReformulationTryFinallyStatements import makeTryFinallyStatement
 from .TreeHelpers import (
     buildNode,
     buildStatementsNode,
     makeStatementsSequence,
-    mergeStatements,
+    makeStatementsSequenceFromStatements,
     popBuildContext,
     pushBuildContext,
 )
@@ -92,8 +88,9 @@ def buildWhileLoopNode(provider, node, source_ref):
     if else_block is not None:
         temp_scope = provider.allocateTempScope("while_loop")
 
+        # Indicator variable, will end up with C bool type, and need not be released.
         tmp_break_indicator = provider.allocateTempVariable(
-            temp_scope=temp_scope, name="break_indicator"
+            temp_scope=temp_scope, name="break_indicator", temp_type="bool"
         )
 
         statements = (
@@ -118,7 +115,7 @@ def buildWhileLoopNode(provider, node, source_ref):
     loop_body = makeStatementsSequence(
         statements=(
             makeStatementConditional(
-                condition=ExpressionOperationNOT(
+                condition=ExpressionOperationNot(
                     operand=buildNode(provider, node.test, source_ref),
                     source_ref=source_ref,
                 ),
@@ -139,7 +136,7 @@ def buildWhileLoopNode(provider, node, source_ref):
     if else_block is None:
         return loop_statement
     else:
-        statements = (
+        return makeStatementsSequenceFromStatements(
             StatementAssignmentVariable(
                 variable=tmp_break_indicator,
                 source=makeConstantRefNode(constant=False, source_ref=source_ref),
@@ -159,18 +156,3 @@ def buildWhileLoopNode(provider, node, source_ref):
                 source_ref=source_ref,
             ),
         )
-
-        statements = (
-            makeTryFinallyStatement(
-                provider=provider,
-                tried=statements,
-                final=StatementReleaseVariable(
-                    variable=tmp_break_indicator, source_ref=source_ref
-                ),
-                source_ref=source_ref,
-            ),
-        )
-
-        return StatementsSequence(
-            statements=mergeStatements(statements, False), source_ref=source_ref
-        )
