@@ -1,4 +1,4 @@
-#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2020, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -31,7 +31,10 @@ from nuitka.nodes.ContainerMakingNodes import (
     ExpressionMakeSetLiteral,
     ExpressionMakeTuple,
 )
-from nuitka.nodes.DictionaryNodes import ExpressionKeyValuePair, ExpressionMakeDict
+from nuitka.nodes.DictionaryNodes import (
+    ExpressionKeyValuePair,
+    ExpressionMakeDict,
+)
 from nuitka.nodes.ExceptionNodes import StatementReraiseException
 from nuitka.nodes.FrameNodes import (
     StatementsFrameAsyncgen,
@@ -44,7 +47,10 @@ from nuitka.nodes.ImportNodes import ExpressionBuiltinImport
 from nuitka.nodes.NodeBases import NodeBase
 from nuitka.nodes.NodeMakingHelpers import mergeStatements
 from nuitka.nodes.StatementNodes import StatementsSequence
-from nuitka.PythonVersions import needsSetLiteralReverseInsertion, python_version
+from nuitka.PythonVersions import (
+    needsSetLiteralReverseInsertion,
+    python_version,
+)
 
 
 def dump(node):
@@ -116,7 +122,6 @@ def detectFunctionBodyKind(nodes, start_value=None):
 
         indications.clear()
         indications.update(old)
-        del old
 
     def _check(node):
         node_class = node.__class__
@@ -223,6 +228,22 @@ def detectFunctionBodyKind(nodes, start_value=None):
                     _check(field[0].iter)
                 else:
                     assert False, (name, field, ast.dump(node))
+        elif python_version >= 370 and node_class is ast.comprehension:
+            for name, field in ast.iter_fields(node):
+                if name in ("name", "target"):
+                    pass
+                elif name == "iter":
+                    # Top level comprehension iterators do not influence those.
+                    if node not in nodes:
+                        _check(field)
+                elif name == "ifs":
+                    for child in field:
+                        _check(child)
+                elif name == "is_async":
+                    if field:
+                        indications.add("Coroutine")
+                else:
+                    assert False, (name, field, ast.dump(node))
         elif node_class is ast.Name:
             if python_version >= 300 and node.id == "super":
                 flags.add("has_super")
